"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Layout = Layout;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _responsive = require("../../utilities/responsive");

var _units = require("../../utilities/units");

var _id = require("../../utilities/id");

var _Layout = _interopRequireDefault(require("./Layout.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

var MEDIAQUERY_MAP = new Map([['small', '@media all and (min-width: 750px)'], ['medium', '@media all and (min-width: 1000px)'], ['large', '@media all and (min-width: 1200px)']]);
var createId = (0, _id.createIdCreator)('Layout');

function Layout(_ref) {
  var _ref$inlineAlignment = _ref.inlineAlignment,
      inlineAlignment = _ref$inlineAlignment === void 0 ? 'center' : _ref$inlineAlignment,
      _ref$blockAlignment = _ref.blockAlignment,
      blockAlignment = _ref$blockAlignment === void 0 ? 'leading' : _ref$blockAlignment,
      maxInlineSize = _ref.maxInlineSize,
      sizes = _ref.sizes,
      spacing = _ref.spacing,
      children = _ref.children;
  var uniqueClassName = createId();
  var CSSSelector = ".".concat(uniqueClassName, " > .").concat(_Layout["default"].LayoutInner);
  var responsiveClassNames = (0, _responsive.useResponsive)({
    spacing: spacing
  });
  var layoutClassName = (0, _cssUtilities.classNames)(_Layout["default"].Layout, uniqueClassName, blockAlignment && _Layout["default"][(0, _cssUtilities.variationName)('blockAlignment', blockAlignment)], inlineAlignment && _Layout["default"][(0, _cssUtilities.variationName)('inlineAlignment', inlineAlignment)]);
  var layoutInnerClassName = (0, _cssUtilities.classNames)(_Layout["default"].LayoutInner, inlineAlignment && _Layout["default"][(0, _cssUtilities.variationName)('LayoutInner-inlineAlignment', inlineAlignment)], blockAlignment && _Layout["default"][(0, _cssUtilities.variationName)('LayoutInner-blockAlignment', blockAlignment)], responsiveClassNames && responsiveClassNames.map(function (className) {
    return _Layout["default"]["LayoutInner-".concat(className)];
  }));
  var layoutStyles = [sizes && generateSizesStyle(CSSSelector, sizes), maxInlineSize && generateMaxInlineSizeStyles(CSSSelector, maxInlineSize)].join(' ');
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: layoutClassName
  }, Boolean(layoutStyles.trim()) && /*#__PURE__*/_react["default"].createElement("style", null, layoutStyles), /*#__PURE__*/_react["default"].createElement("div", {
    className: layoutInnerClassName
  }, _react["default"].Children.map(children, function (child) {
    return /*#__PURE__*/_react["default"].createElement("div", {
      className: (0, _cssUtilities.classNames)(_Layout["default"].LayoutInnerSpacing, responsiveClassNames && responsiveClassNames.map(function (className) {
        return _Layout["default"]["LayoutInnerSpacing-".concat(className)];
      }))
    }, /*#__PURE__*/_react["default"].createElement("div", null, child));
  })));
}

function generateSizesStyles(selector, sizes) {
  return sizes.reduce(function (acc, basicSize, index) {
    var mustFill = basicSize === 'fill';
    var sizeStyles = typeof basicSize === 'number' ? "flex: 0 0 ".concat((0, _units.pixelOrPercent)(basicSize), ";") : 'flex: 0 1 auto;';
    var inlineStyles = "\n        ".concat(selector, " > :nth-child(").concat(index + 1, ") {\n          ").concat(mustFill ? 'flex: 1 0px;' : "".concat(sizeStyles), "\n        }\n      ");
    return [acc, inlineStyles].join(' ');
  }, '');
}

function generateSizesStyle(selector, sizes) {
  if (Array.isArray(sizes) || _typeof(sizes) !== 'object') {
    var sizesStyles = sizes && generateSizesStyles(selector, sizes);
    var wrappingStyles = (sizes === null || sizes === void 0 ? void 0 : sizes.includes(1)) ? "".concat(selector, " { flex-wrap: wrap; }") : "".concat(selector, " { flex-wrap: nowrap; }");
    return [sizesStyles, wrappingStyles].join(' ');
  }

  return Object.entries(sizes).reduce(function (acc, _ref2) {
    var _ref3 = _slicedToArray(_ref2, 2),
        breakpoint = _ref3[0],
        sizes = _ref3[1];

    var sizesStyles = sizes && generateSizesStyles(selector, sizes);
    var wrappingStyles = (sizes === null || sizes === void 0 ? void 0 : sizes.includes(1)) ? "".concat(selector, " { flex-wrap: wrap; }") : "".concat(selector, " { flex-wrap: nowrap; }");
    var mediaStyles = [sizesStyles, wrappingStyles];
    var inlineStyles = breakpoint === 'base' ? mediaStyles : [MEDIAQUERY_MAP.get(breakpoint), '{'].concat(mediaStyles, ['}']);
    return [acc].concat(_toConsumableArray(inlineStyles)).join(' ');
  }, '');
}

function generateMaxInlineSizeStyles(selector, maxInlineSize) {
  if (_typeof(maxInlineSize) !== 'object') {
    return maxInlineSize ? "".concat(selector, " { max-width: ").concat((0, _units.pixelOrPercent)(maxInlineSize), "; }") : '';
  }

  return Object.entries(maxInlineSize).reduce(function (acc, _ref4) {
    var _ref5 = _slicedToArray(_ref4, 2),
        breakpoint = _ref5[0],
        maxInlineSize = _ref5[1];

    var maxInlineSizeStyles = maxInlineSize ? "".concat(selector, " { max-width: ").concat((0, _units.pixelOrPercent)(maxInlineSize), "; }") : '';
    var inlineStyles = breakpoint === 'base' ? maxInlineSizeStyles : [MEDIAQUERY_MAP.get(breakpoint), '{', maxInlineSizeStyles, '}'];
    return [acc].concat(_toConsumableArray(inlineStyles)).join(' ');
  }, '');
}