"use strict";

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _Portal = require("../Portal");

var _Heading = require("../Heading");

var _Modal = require("./Modal");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

describe('<Modal />', function () {
  var defaultIFrameSrc = _faker["default"].internet.url();

  describe('open prop', function () {
    it('renders the modal when the open prop is true', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
      var modal;
      return _regenerator["default"].wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                open: true,
                src: defaultIFrameSrc
              }));

            case 2:
              modal = _context.sent;
              expect(modal).toContainReactComponent(_Portal.Portal);

            case 4:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    })));
    it("doesn't render the modal when the open prop is undefined", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee2() {
      var modal;
      return _regenerator["default"].wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              _context2.next = 2;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                src: defaultIFrameSrc
              }));

            case 2:
              modal = _context2.sent;
              expect(modal).not.toContainReactComponent(_Portal.Portal);

            case 4:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    })));
    it('calls onClose when open changes from true to false', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee3() {
      var onCloseSpy, modal;
      return _regenerator["default"].wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              onCloseSpy = jest.fn();
              _context3.next = 3;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                onClose: onCloseSpy,
                src: defaultIFrameSrc,
                open: true
              }));

            case 3:
              modal = _context3.sent;
              modal.setProps({
                open: false
              });
              expect(onCloseSpy).toHaveBeenCalledTimes(1);

            case 6:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3);
    })));
  });
  it('renders an iframe is the src prop is passed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee4() {
    var iFrameSrc, iFrameName, modal;
    return _regenerator["default"].wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            iFrameSrc = _faker["default"].internet.url();
            iFrameName = _faker["default"].random.words(2);
            _context4.next = 4;
            return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
              src: iFrameSrc,
              iFrameName: iFrameName,
              open: true
            }));

          case 4:
            modal = _context4.sent;
            expect(modal).toContainReactComponent('iframe', {
              src: iFrameSrc,
              name: iFrameName
            });

          case 6:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('renders its children if no src prop is passed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee5() {
    var content, modal;
    return _regenerator["default"].wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            content = _faker["default"].random.words(2);
            _context5.next = 3;
            return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
              open: true
            }, /*#__PURE__*/_react["default"].createElement("p", null, content)));

          case 3:
            modal = _context5.sent;
            expect(modal).not.toContainReactComponent('iframe');
            expect(modal).toContainReactText(content);

          case 6:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('renders a header with Heading if the title prop is passed', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee6() {
    var title, modal;
    return _regenerator["default"].wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            title = _faker["default"].random.words(2);
            _context6.next = 3;
            return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
              src: defaultIFrameSrc,
              title: title,
              open: true
            }));

          case 3:
            modal = _context6.sent;
            expect(modal).toContainReactComponent('header');
            expect(modal).toContainReactComponent(_Heading.Heading);
            expect(modal).toContainReactText(title);

          case 7:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('does not render a Heading if titleHidden', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee7() {
    var title, modal;
    return _regenerator["default"].wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            title = _faker["default"].random.words(2);
            _context7.next = 3;
            return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
              src: defaultIFrameSrc,
              title: title,
              open: true,
              titleHidden: true
            }));

          case 3:
            modal = _context7.sent;
            expect(modal).not.toContainReactComponent(_Heading.Heading);

          case 5:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('still renders a close button if no title', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee8() {
    var modal;
    return _regenerator["default"].wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            _context8.next = 2;
            return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
              src: defaultIFrameSrc,
              open: true
            }));

          case 2:
            modal = _context8.sent;
            expect(modal).toContainReactComponent('button');

          case 4:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('still renders a close button if titleHidden', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee9() {
    var modal;
    return _regenerator["default"].wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            _context9.next = 2;
            return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
              src: defaultIFrameSrc,
              open: true,
              titleHidden: true
            }));

          case 2:
            modal = _context9.sent;
            expect(modal).toContainReactComponent('button');

          case 4:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  describe('when the escape key is pressed', function () {
    it('closes the modal', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee10() {
      var modal, event;
      return _regenerator["default"].wrap(function _callee10$(_context10) {
        while (1) {
          switch (_context10.prev = _context10.next) {
            case 0:
              _context10.next = 2;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                src: defaultIFrameSrc,
                open: true
              }));

            case 2:
              modal = _context10.sent;
              event = new KeyboardEvent('keydown', {
                key: 'Escape'
              });
              modal.act(function () {
                return document.dispatchEvent(event);
              });
              expect(modal).not.toContainReactComponent(_Portal.Portal);

            case 6:
            case "end":
              return _context10.stop();
          }
        }
      }, _callee10);
    })));
    it('calls onClose callback', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee11() {
      var onCloseSpy, modal, event;
      return _regenerator["default"].wrap(function _callee11$(_context11) {
        while (1) {
          switch (_context11.prev = _context11.next) {
            case 0:
              onCloseSpy = jest.fn();
              _context11.next = 3;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                onClose: onCloseSpy,
                open: true
              }, "Hi"));

            case 3:
              modal = _context11.sent;
              event = new KeyboardEvent('keydown', {
                key: 'Escape'
              });
              modal.act(function () {
                return document.dispatchEvent(event);
              });
              expect(onCloseSpy).toHaveBeenCalledTimes(1);

            case 7:
            case "end":
              return _context11.stop();
          }
        }
      }, _callee11);
    })));
  });
  describe('when the close button is clicked', function () {
    it('closes the modal', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee12() {
      var _modal$find;

      var modal;
      return _regenerator["default"].wrap(function _callee12$(_context12) {
        while (1) {
          switch (_context12.prev = _context12.next) {
            case 0:
              _context12.next = 2;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                src: defaultIFrameSrc,
                title: "A modal",
                open: true
              }));

            case 2:
              modal = _context12.sent;
              (_modal$find = modal.find('button')) === null || _modal$find === void 0 ? void 0 : _modal$find.trigger('onClick');
              expect(modal).not.toContainReactComponent(_Portal.Portal);

            case 5:
            case "end":
              return _context12.stop();
          }
        }
      }, _callee12);
    })));
    it('calls onClose callback', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee13() {
      var _modal$find2;

      var onCloseSpy, modal;
      return _regenerator["default"].wrap(function _callee13$(_context13) {
        while (1) {
          switch (_context13.prev = _context13.next) {
            case 0:
              onCloseSpy = jest.fn();
              _context13.next = 3;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                title: "A modal",
                onClose: onCloseSpy,
                open: true
              }, "Hi"));

            case 3:
              modal = _context13.sent;
              (_modal$find2 = modal.find('button')) === null || _modal$find2 === void 0 ? void 0 : _modal$find2.trigger('onClick');
              expect(onCloseSpy).toHaveBeenCalledTimes(1);

            case 6:
            case "end":
              return _context13.stop();
          }
        }
      }, _callee13);
    })));
    it('resets the iFrameHeight', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee14() {
      var _modal$find3, _modal$find4;

      var expectedHeight, fakeEvent, modal;
      return _regenerator["default"].wrap(function _callee14$(_context14) {
        while (1) {
          switch (_context14.prev = _context14.next) {
            case 0:
              expectedHeight = 100;
              fakeEvent = {
                target: {
                  contentWindow: {
                    document: {
                      body: {
                        scrollHeight: expectedHeight
                      }
                    }
                  }
                }
              };
              _context14.next = 4;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                title: "A modal",
                src: defaultIFrameSrc,
                open: true
              }));

            case 4:
              modal = _context14.sent;
              (_modal$find3 = modal.find('iframe')) === null || _modal$find3 === void 0 ? void 0 : _modal$find3.trigger('onLoad', fakeEvent);
              expect(modal.find('iframe').prop('style')).toMatchObject({
                height: "".concat(expectedHeight, "px")
              });
              (_modal$find4 = modal.find('button')) === null || _modal$find4 === void 0 ? void 0 : _modal$find4.trigger('onClick');
              modal.setProps({
                open: false
              });
              modal.setProps({
                open: true
              });
              expect(modal.find('iframe').prop('style')).toBeUndefined();

            case 11:
            case "end":
              return _context14.stop();
          }
        }
      }, _callee14);
    })));
  });
  describe('blocking prop', function () {
    it("doesn't render the close button", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee15() {
      var modal;
      return _regenerator["default"].wrap(function _callee15$(_context15) {
        while (1) {
          switch (_context15.prev = _context15.next) {
            case 0:
              _context15.next = 2;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                src: defaultIFrameSrc,
                title: "A modal",
                open: true,
                blocking: true
              }));

            case 2:
              modal = _context15.sent;
              expect(modal).not.toContainReactComponent('button');

            case 4:
            case "end":
              return _context15.stop();
          }
        }
      }, _callee15);
    })));
    it("doesn't close the modal when the escape key is pressed", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee16() {
      var modal, event;
      return _regenerator["default"].wrap(function _callee16$(_context16) {
        while (1) {
          switch (_context16.prev = _context16.next) {
            case 0:
              _context16.next = 2;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                src: defaultIFrameSrc,
                open: true,
                blocking: true
              }));

            case 2:
              modal = _context16.sent;
              event = new KeyboardEvent('keydown', {
                key: 'Escape'
              });
              modal.act(function () {
                return document.dispatchEvent(event);
              });
              expect(modal).toContainReactComponent(_Portal.Portal);

            case 6:
            case "end":
              return _context16.stop();
          }
        }
      }, _callee16);
    })));
  });
  describe('long prop', function () {
    it("doesn't add the onLoad prop when present", /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee17() {
      var modal, iframe;
      return _regenerator["default"].wrap(function _callee17$(_context17) {
        while (1) {
          switch (_context17.prev = _context17.next) {
            case 0:
              _context17.next = 2;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                src: defaultIFrameSrc,
                open: true,
                "long": true
              }));

            case 2:
              modal = _context17.sent;
              iframe = modal.find('iframe');
              expect(iframe === null || iframe === void 0 ? void 0 : iframe.prop('onLoad')).toBeUndefined();

            case 5:
            case "end":
              return _context17.stop();
          }
        }
      }, _callee17);
    })));
    it('adds the onLoad prop when absent', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regenerator["default"].mark(function _callee18() {
      var modal, iframe;
      return _regenerator["default"].wrap(function _callee18$(_context18) {
        while (1) {
          switch (_context18.prev = _context18.next) {
            case 0:
              _context18.next = 2;
              return (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Modal.Modal, {
                src: defaultIFrameSrc,
                open: true
              }));

            case 2:
              modal = _context18.sent;
              iframe = modal.find('iframe');
              expect(iframe === null || iframe === void 0 ? void 0 : iframe.prop('onLoad')).not.toBeUndefined();

            case 5:
            case "end":
              return _context18.stop();
          }
        }
      }, _callee18);
    })));
  });
});