"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../../../test-utilities");

var _Checkbox = require("../../../Checkbox");

var _RadioControl = require("../../../RadioControl");

var _View = require("../../../View");

var _OptionList = require("../../OptionList");

var _Option = require("./Option");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var defaultProps = {
  id: _faker["default"].random.uuid(),
  label: _faker["default"].random.word()
};
var defaultOptionListProps = {
  id: _faker["default"].random.uuid(),
  selectedItems: [],
  onChange: function onChange() {
    return null;
  },
  children: /*#__PURE__*/_react["default"].createElement("div", null)
};
describe('<Option />', function () {
  it('triggers onChange when input is selected', function () {
    var id = _faker["default"].random.uuid();

    var onChangeSpy = jest.fn();
    var optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
      onChange: onChangeSpy
    }), /*#__PURE__*/_react["default"].createElement(_Option.Option, Object.assign({}, defaultProps, {
      id: id
    }))));
    optionList.find(_Option.Option).find(_RadioControl.RadioControl).trigger('onChange');
    expect(onChangeSpy).toHaveBeenCalledWith([id]);
  });
  it('input is active if selected', function () {
    var id = _faker["default"].random.uuid();

    var optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
      selectedItems: [id]
    }), /*#__PURE__*/_react["default"].createElement(_Option.Option, Object.assign({}, defaultProps, {
      id: id
    }))));
    expect(optionList.find(_Option.Option)).toContainReactComponent('input', {
      checked: true
    });
  });
  it('renders a RadioControl if allow multiple is false', function () {
    var optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, defaultOptionListProps, /*#__PURE__*/_react["default"].createElement(_Option.Option, defaultProps)));
    expect(optionList.find(_Option.Option)).toContainReactComponent(_RadioControl.RadioControl);
  });
  it('renders a CheckboxControl if allow multiple is true', function () {
    var optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
      allowMultiple: true
    }), /*#__PURE__*/_react["default"].createElement(_Option.Option, defaultProps)));
    expect(optionList.find(_Option.Option)).toContainReactComponent(_Checkbox.CheckboxControl);
  });
  it('renders visually hidden View when label and childrens are set', function () {
    var labelContent = _faker["default"].random.word();

    var optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, defaultOptionListProps, /*#__PURE__*/_react["default"].createElement(_Option.Option, Object.assign({}, defaultProps, {
      label: labelContent
    }), "Childrens")));
    expect(optionList.find(_View.View, {
      visibility: 'hidden'
    })).toContainReactText(labelContent);
  });
  describe('allowMultiple', function () {
    it('allows the selection of multiple options', function () {
      var firstItem = _faker["default"].random.uuid();

      var secondItem = _faker["default"].random.uuid();

      var optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
        allowMultiple: true,
        selectedItems: [firstItem, secondItem]
      }), /*#__PURE__*/_react["default"].createElement(_Option.Option, Object.assign({}, defaultProps, {
        id: firstItem
      })), /*#__PURE__*/_react["default"].createElement(_Option.Option, Object.assign({}, defaultProps, {
        id: secondItem
      }))));

      var _optionList$findAll = optionList.findAll(_Option.Option),
          _optionList$findAll2 = _slicedToArray(_optionList$findAll, 2),
          firstOption = _optionList$findAll2[0],
          secondOption = _optionList$findAll2[1];

      expect(firstOption).toContainReactComponent(_Checkbox.CheckboxControl, {
        checked: true
      });
      expect(secondOption).toContainReactComponent(_Checkbox.CheckboxControl, {
        checked: true
      });
    });
    it('toggles the selection of already selection options', function () {
      var selected = _faker["default"].random.uuid();

      var onChangeSpy = jest.fn();
      var optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
        allowMultiple: true,
        selectedItems: [selected],
        onChange: onChangeSpy
      }), /*#__PURE__*/_react["default"].createElement(_Option.Option, Object.assign({}, defaultProps, {
        id: selected
      }))));
      optionList.find(_Option.Option).find(_Checkbox.CheckboxControl).trigger('onChange');
      expect(onChangeSpy).toHaveBeenCalledWith([]);
    });
  });
  describe('controlHidden', function () {
    it('shows control by default', function () {
      var optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, defaultOptionListProps, /*#__PURE__*/_react["default"].createElement(_Option.Option, defaultProps)));
      expect(optionList.find(_Option.Option)).toContainReactComponent(_RadioControl.RadioControl);
    });
    it('hides control when true', function () {
      var optionList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_OptionList.OptionList, Object.assign({}, defaultOptionListProps, {
        controlHidden: true
      }), /*#__PURE__*/_react["default"].createElement(_Option.Option, defaultProps)));
      expect(optionList.find(_Option.Option)).not.toContainReactComponent(_RadioControl.RadioControl);
    });
  });
});