"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Field = exports.TextFieldInternal = exports.TextField = void 0;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _View = require("../View");

var _Labelled = require("../Labelled");

var _Icon = require("../Icon");

var _InlineError = require("../InlineError");

var _BlockStack = require("../BlockStack");

var _Theme = require("../Theme");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _strings = require("../../utilities/strings");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _autocomplete = require("../../utilities/autocomplete");

var _forms = require("../../utilities/forms");

var _TextField = _interopRequireDefault(require("./TextField.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var createId = (0, _id.createIdCreator)('TextField');

/**
 * A text field is an input field that merchants can type into.
 */
var TextField = /*#__PURE__*/(0, _react.forwardRef)(function (props, ref) {
  return /*#__PURE__*/_react["default"].createElement(TextFieldInternal, Object.assign({}, props, {
    ref: ref
  }));
});
exports.TextField = TextField;
var TextFieldInternal = /*#__PURE__*/(0, _react.forwardRef)(function (props, ref) {
  var _useThemeConfiguratio = (0, _Theme.useThemeConfiguration)(),
      controlsBackground = _useThemeConfiguratio.controls.background,
      _useThemeConfiguratio2 = _useThemeConfiguratio.textFields,
      labelPosition = _useThemeConfiguratio2.labelPosition,
      textFieldsBackground = _useThemeConfiguratio2.background,
      errorIndentation = _useThemeConfiguratio2.errorIndentation,
      errorTypographyStyle = _useThemeConfiguratio2.errorTypographyStyle;

  var background = textFieldsBackground || controlsBackground || 'surfaceTertiary';
  var accessibilityDescription = props.accessibilityDescription,
      error = props.error,
      explicitId = props.id,
      label = props.label,
      explicitValue = props.value,
      controlledValue = props.controlledValue,
      onInput = props.onInput,
      children = props.children,
      multiline = props.multiline,
      onChange = props.onChange;
  var wrapperRef = (0, _react.useRef)(null);

  var _useState = (0, _react.useState)(false),
      _useState2 = _slicedToArray(_useState, 2),
      focus = _useState2[0],
      setFocus = _useState2[1];

  (0, _react.useLayoutEffect)(function () {
    if (!(wrapperRef === null || wrapperRef === void 0 ? void 0 : wrapperRef.current)) return;

    var handleFocus = function handleFocus() {
      setFocus(true);
    };

    var handleBlur = function handleBlur() {
      setFocus(false);
    };

    var fields = wrapperRef.current.querySelectorAll('input, textarea, select');

    var _iterator = _createForOfIteratorHelper(fields),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var field = _step.value;
        field.addEventListener('focus', handleFocus);
        field.addEventListener('blur', handleBlur);
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }

    return function () {
      var _iterator2 = _createForOfIteratorHelper(fields),
          _step2;

      try {
        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
          var field = _step2.value;
          field.removeEventListener('focus', handleFocus);
          field.removeEventListener('blur', handleBlur);
        }
      } catch (err) {
        _iterator2.e(err);
      } finally {
        _iterator2.f();
      }
    };
  }, [children]);
  var id = (0, _id.useId)(explicitId, createId);
  var descriptionId = accessibilityDescription ? "".concat(id, "-description") : undefined;
  var description = descriptionId ? /*#__PURE__*/_react["default"].createElement(_View.View, {
    visibility: "hidden",
    id: descriptionId
  }, accessibilityDescription) : null;

  var _usePartiallyControll = usePartiallyControlledState(controlledValue !== null && controlledValue !== void 0 ? controlledValue : explicitValue),
      _usePartiallyControll2 = _slicedToArray(_usePartiallyControll, 2),
      localValue = _usePartiallyControll2[0],
      setLocalValue = _usePartiallyControll2[1];

  var handleInput = (0, _react.useCallback)(function (value) {
    onInput === null || onInput === void 0 ? void 0 : onInput(value);
    setLocalValue(value);
  }, [onInput, setLocalValue]);

  var errorMarkup = error && error !== true && /*#__PURE__*/_react["default"].createElement("span", {
    className: (0, _cssUtilities.classNames)(errorIndentation && _TextField["default"][(0, _cssUtilities.variationName)('Error-errorIndentation', errorIndentation)], errorTypographyStyle && _typographyStyles["default"][errorTypographyStyle])
  }, /*#__PURE__*/_react["default"].createElement(_InlineError.InlineError, {
    controlID: id
  }, error));

  function handleKeyDown(event) {
    if (multiline === false || !onChange) {
      return;
    }

    switch (event.key) {
      case 'Enter':
        onChange(event.currentTarget.value);
    }
  }

  return /*#__PURE__*/_react["default"].createElement(_BlockStack.BlockStack, {
    spacing: "tight"
  }, /*#__PURE__*/_react["default"].createElement(_Labelled.Labelled, {
    label: label,
    htmlFor: id,
    empty: (0, _strings.isEmptyString)(localValue),
    position: labelPosition,
    background: background,
    subdued: props.readonly,
    prefixed: Boolean(props.prefix),
    hasIcon: Boolean(props.icon)
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: (0, _cssUtilities.classNames)(_TextField["default"].Wrapper, props.disabled && _TextField["default"]['Wrapper-disabled'], props.readonly && _TextField["default"]['Wrapper-readonly'], _TextField["default"][(0, _cssUtilities.variationName)('Wrapper-background', background)]),
    ref: wrapperRef
  }, description, /*#__PURE__*/_react["default"].createElement(Field, Object.assign({
    ref: ref
  }, props, {
    id: id,
    focus: focus,
    ariaDescribedBy: descriptionId,
    localValue: localValue,
    onInput: handleInput,
    onKeyDown: handleKeyDown
  })))), errorMarkup);
});
exports.TextFieldInternal = TextFieldInternal;
var Field = /*#__PURE__*/(0, _react.forwardRef)(function Field(_ref, ref) {
  var id = _ref.id,
      min = _ref.min,
      max = _ref.max,
      step = _ref.step,
      maxLength = _ref.maxLength,
      name = _ref.name,
      label = _ref.label,
      prefix = _ref.prefix,
      icon = _ref.icon,
      suffix = _ref.suffix,
      explicitValue = _ref.value,
      localValue = _ref.localValue,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      role = _ref.role,
      required = _ref.required,
      error = _ref.error,
      focus = _ref.focus,
      autocomplete = _ref.autocomplete,
      autofocus = _ref.autofocus,
      multiline = _ref.multiline,
      disabled = _ref.disabled,
      readonly = _ref.readonly,
      children = _ref.children,
      ariaActiveDescendant = _ref.ariaActiveDescendant,
      ariaAutocomplete = _ref.ariaAutocomplete,
      ariaControls = _ref.ariaControls,
      ariaDescribedBy = _ref.ariaDescribedBy,
      ariaExpanded = _ref.ariaExpanded,
      _onFocus = _ref.onFocus,
      _onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onInput = _ref.onInput,
      onKeyDown = _ref.onKeyDown;
  var innerRef = (0, _react.useRef)();
  var refsSetter = (0, _react.useCallback)(function (instance) {
    if (typeof ref === 'function') {
      ref(instance);
    } else if (ref) {
      ref.current = instance;
    }

    innerRef.current = instance;
  }, [ref]);
  var form = (0, _forms.useContainingForm)();
  (0, _react.useEffect)(function () {
    if (autofocus) {
      var _innerRef$current;

      (_innerRef$current = innerRef.current) === null || _innerRef$current === void 0 ? void 0 : _innerRef$current.focus();
    }
  }, [autofocus]);

  var _useThemeConfiguratio3 = (0, _Theme.useThemeConfiguration)(),
      controlsBackground = _useThemeConfiguratio3.controls.background,
      _useThemeConfiguratio4 = _useThemeConfiguratio3.textFields,
      _useThemeConfiguratio5 = _useThemeConfiguratio4.labelPosition,
      labelPosition = _useThemeConfiguratio5 === void 0 ? 'inside' : _useThemeConfiguratio5,
      textFieldsBackground = _useThemeConfiguratio4.background,
      _useThemeConfiguratio6 = _useThemeConfiguratio4.border,
      border = _useThemeConfiguratio6 === void 0 ? 'full' : _useThemeConfiguratio6,
      _useThemeConfiguratio7 = _useThemeConfiguratio4.borderColor,
      borderColor = _useThemeConfiguratio7 === void 0 ? 'base' : _useThemeConfiguratio7,
      _useThemeConfiguratio8 = _useThemeConfiguratio4.focusBorder,
      focusBorder = _useThemeConfiguratio8 === void 0 ? 'full' : _useThemeConfiguratio8,
      style = _useThemeConfiguratio4.typographyStyle,
      placeholderStyle = _useThemeConfiguratio3.label.typographyStyle;

  var background = textFieldsBackground || controlsBackground || 'surfaceTertiary';
  var labelled = (0, _Labelled.useLabelled)();
  var fieldWrapperClassName = (0, _cssUtilities.classNames)(_TextField["default"]['Field-Wrapper'], Boolean(multiline) && _TextField["default"].multiline);

  var iconMarkup = icon && /*#__PURE__*/_react["default"].createElement("div", {
    className: _TextField["default"].Icon,
    "aria-hidden": "true",
    onClick: function onClick() {
      var _innerRef$current2;

      return (_innerRef$current2 = innerRef.current) === null || _innerRef$current2 === void 0 ? void 0 : _innerRef$current2.focus();
    }
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: _TextField["default"].IconInner
  }, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    appearance: "subdued",
    source: icon
  })));

  var prefixMarkup = prefix && (labelled.floating || labelPosition === 'outside') && /*#__PURE__*/_react["default"].createElement("div", {
    id: "".concat(id, "-prefix"),
    className: (0, _cssUtilities.classNames)(_TextField["default"].Prefix, labelPosition === 'inside' && _TextField["default"]['Prefix-inside']),
    "aria-hidden": "true",
    onClick: function onClick() {
      var _innerRef$current3;

      return (_innerRef$current3 = innerRef.current) === null || _innerRef$current3 === void 0 ? void 0 : _innerRef$current3.focus();
    }
  }, prefix);

  var className = (0, _cssUtilities.classNames)(_TextField["default"].Field, labelled.floating && labelPosition !== 'outside' && _TextField["default"]['Field-floating'], Boolean(prefix) && _TextField["default"]['Field-prefixed'], Boolean(children) && _TextField["default"]['Field-hasActions'], Boolean(multiline) && _TextField["default"]['Field-multiline'], style && _typographyStyles["default"][style], placeholderStyle && _typographyStyles["default"][(0, _cssUtilities.variationName)('placeholder', placeholderStyle)]);
  var backdropClassName = (0, _cssUtilities.classNames)(_TextField["default"].Backdrop, focus && _TextField["default"].focus, Boolean(error) && _TextField["default"].hasError, _TextField["default"][(0, _cssUtilities.variationName)('Backdrop-background', background)], _TextField["default"][(0, _cssUtilities.variationName)('Backdrop-border', border)], _TextField["default"][(0, _cssUtilities.variationName)('Backdrop-borderColor', borderColor)], _TextField["default"][(0, _cssUtilities.variationName)('Backdrop-focusBorder', focusBorder)], disabled && _TextField["default"]['Backdrop-disabled'], readonly && _TextField["default"]['Backdrop-readOnly']);
  var finalDescribedBy = [ariaDescribedBy, error && (0, _errors.errorId)(id)].filter(Boolean).join(' ');

  var field = /*#__PURE__*/_react["default"].createElement(multiline ? 'textarea' : 'input', {
    id: id,
    min: min,
    max: max,
    step: step,
    maxLength: maxLength,
    name: name,
    placeholder: labelled.floating || labelPosition === 'outside' ? undefined : label,
    className: className,
    required: required,
    type: normalizeType(multiline ? undefined : type),
    disabled: disabled,
    readOnly: readonly,
    'aria-activedescendant': ariaActiveDescendant,
    'aria-autocomplete': ariaAutocomplete,
    'aria-controls': ariaControls,
    'aria-describedby': finalDescribedBy,
    'aria-expanded': ariaExpanded,
    'aria-invalid': Boolean(error),
    'aria-required': required,
    'aria-labelledby': "".concat(id, "-label").concat(prefix ? " ".concat(id, "-prefix") : '').concat(suffix ? " ".concat(id, "-suffix") : ''),
    onBlur: function onBlur(_ref2) {
      var value = _ref2.currentTarget.value;
      var currentValue = explicitValue;
      if (value !== currentValue) onChange === null || onChange === void 0 ? void 0 : onChange(value);
      _onBlur === null || _onBlur === void 0 ? void 0 : _onBlur();
      labelled.onBlur();
    },
    onChange: function onChange(_ref3) {
      var value = _ref3.currentTarget.value;
      onInput === null || onInput === void 0 ? void 0 : onInput(value);
    },
    onFocus: function onFocus() {
      _onFocus === null || _onFocus === void 0 ? void 0 : _onFocus();
      labelled.onFocus();
    },
    onKeyDown: onKeyDown,
    ref: refsSetter,
    role: role,
    rows: normalizeMultiline(multiline),
    value: localValue !== null && localValue !== void 0 ? localValue : '',
    autoComplete: (0, _autocomplete.autocompleteToHtml)(autocomplete),
    autofocus: autofocus,
    form: (form === null || form === void 0 ? void 0 : form.nested) ? form.id : undefined
  });

  var multilineClone = Boolean(multiline) === true && /*#__PURE__*/_react["default"].createElement("div", {
    "aria-hidden": "true",
    className: (0, _cssUtilities.classNames)(_TextField["default"].MultilineClone, className)
  }, localValue, ' '
  /* prevents jump with last return carriage */
  );

  var suffixMarkup = suffix && /*#__PURE__*/_react["default"].createElement("div", {
    id: "".concat(id, "-suffix"),
    className: _TextField["default"].Suffix,
    "aria-hidden": "true",
    onClick: function onClick() {
      var _innerRef$current4;

      return (_innerRef$current4 = innerRef.current) === null || _innerRef$current4 === void 0 ? void 0 : _innerRef$current4.focus();
    }
  }, suffix);

  var actions = children && !disabled && /*#__PURE__*/_react["default"].createElement("div", {
    className: _TextField["default"].Actions
  }, children);

  return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, iconMarkup, prefixMarkup, /*#__PURE__*/_react["default"].createElement("div", {
    className: fieldWrapperClassName
  }, field, /*#__PURE__*/_react["default"].createElement("div", {
    className: backdropClassName
  }), multilineClone), suffixMarkup, actions);
});
exports.Field = Field;

function usePartiallyControlledState(value) {
  var _useState3 = (0, _react.useState)(value),
      _useState4 = _slicedToArray(_useState3, 2),
      localValue = _useState4[0],
      setLocalValue = _useState4[1];

  var lastExplicitValue = (0, _react.useRef)(value);
  var valueToReturn = localValue;

  if (lastExplicitValue.current !== value) {
    lastExplicitValue.current = value;
    setLocalValue(value);
    valueToReturn = value;
  }

  return [valueToReturn, setLocalValue];
} // Takes the `type` we allow for a TextField props, and maps it to the
// valid type for an HTML input. Currently, the only difference is
// that we use the full word `telephone` instead of `tel`.


function normalizeType(type) {
  return type === 'telephone' ? 'tel' : type;
}

function normalizeMultiline(multiline) {
  switch (_typeof(multiline)) {
    case 'undefined':
      return false;

    case 'boolean':
      return multiline ? '1' : false;

    case 'number':
      return multiline;
  }
}