"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _index = require("./index");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var defaultProps = {
  id: _faker["default"].random.uuid(),
  selectedItem: _faker["default"].random.uuid(),
  onChange: function onChange() {
    return null;
  }
};
describe('<ToggleButton />', function () {
  it('renders its children', function () {
    var id = _faker["default"].random.uuid();

    function Children() {
      return /*#__PURE__*/_react["default"].createElement("div", null, "children");
    }

    var toggleButtonGroup = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_index.ToggleButtonGroup, defaultProps, /*#__PURE__*/_react["default"].createElement(_index.ToggleButton, {
      id: id
    }, /*#__PURE__*/_react["default"].createElement(Children, null))));
    expect(toggleButtonGroup).toContainReactComponent(Children);
  });
  describe('onChange', function () {
    it('triggers onChange when button is selected', function () {
      var id = _faker["default"].random.uuid();

      var onChangeSpy = jest.fn();
      var toggleButtonGroup = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_index.ToggleButtonGroup, Object.assign({}, defaultProps, {
        onChange: onChangeSpy
      }), /*#__PURE__*/_react["default"].createElement(_index.ToggleButton, {
        id: id
      })));
      toggleButtonGroup.find('button').trigger('onClick');
      expect(onChangeSpy).toHaveBeenCalledWith(id);
    });
  });
  describe('aria-pressed', function () {
    it('aria-pressed corresponds to not selected', function () {
      var id = _faker["default"].random.uuid();

      var toggleButtonGroup = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_index.ToggleButtonGroup, defaultProps, /*#__PURE__*/_react["default"].createElement(_index.ToggleButton, {
        id: id
      })));
      expect(toggleButtonGroup).toContainReactComponent('button', {
        'aria-pressed': false
      });
    });
    it('aria-pressed corresponds to selected', function () {
      var id = _faker["default"].random.uuid();

      var toggleButtonGroup = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_index.ToggleButtonGroup, Object.assign({}, defaultProps, {
        selectedItem: id
      }), /*#__PURE__*/_react["default"].createElement(_index.ToggleButton, {
        id: id
      })));
      expect(toggleButtonGroup).toContainReactComponent('button', {
        'aria-pressed': true
      });
    });
  });
});