"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _View = require("./View");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe('<View />', function () {
  describe('children', function () {
    it('renders its children', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, null, text, " "));
      expect(view).toContainReactText(text);
    });
  });
  describe('display', function () {
    it('renders a div by default', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, null, text, " "));
      expect(view).toContainReactComponent('div');
    });
    it('renders a span when "inline" is set', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, {
        display: "inline"
      }, text, " "));
      expect(view).toContainReactComponent('span');
    });
    it('renders a div when "block" is set', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, {
        display: "block"
      }, text, " "));
      expect(view).toContainReactComponent('div');
    });
  });
  describe('accessibilityVisibility', function () {
    it('sets aria-hidden to true when accessibilityVisibility is set', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, {
        accessibilityVisibility: "hidden"
      }, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': true
      });
    });
    it('sets aria-hidden to false when accessibilityVisibility is not set', function () {
      var text = 'Snowdevil';
      var view = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_View.View, null, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': false
      });
    });
  });
});