"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateResponsiveClassnames = generateResponsiveClassnames;
exports.convertLogicalProps = convertLogicalProps;
exports.useResponsive = useResponsive;

var _cssUtilities = require("@shopify/css-utilities");

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var classNamesMap = {
  padding: ['paddingInlineStart', 'paddingInlineEnd', 'paddingBlockStart', 'paddingBlockEnd'],
  paddingInline: ['paddingInlineStart', 'paddingInlineEnd'],
  paddingInlineStart: 'paddingInlineStart',
  paddingInlineEnd: 'paddingInlineEnd',
  paddingBlock: ['paddingBlockStart', 'paddingBlockEnd'],
  paddingBlockStart: 'paddingBlockStart',
  paddingBlockEnd: 'paddingBlockEnd',
  background: 'background',
  border: ['borderInlineStart', 'borderInlineEnd', 'borderBlockStart', 'borderBlockEnd'],
  borderInline: ['borderInlineStart', 'borderInlineEnd'],
  borderInlineStart: 'borderInlineStart',
  borderInlineEnd: 'borderInlineEnd',
  borderBlock: ['borderBlockStart', 'borderBlockEnd'],
  borderBlockStart: 'borderBlockStart',
  borderBlockEnd: 'borderBlockEnd',
  borderWidth: ['borderWidthInlineStart', 'borderWidthInlineEnd', 'borderWidthBlockStart', 'borderWidthBlockEnd'],
  borderWidthInline: ['borderWidthInlineStart', 'borderWidthInlineEnd'],
  borderWidthInlineStart: 'borderWidthInlineStart',
  borderWidthInlineEnd: 'borderWidthInlineEnd',
  borderWidthBlock: ['borderWidthBlockStart', 'borderWidthBlockEnd'],
  borderWidthBlockStart: 'borderWidthBlockStart',
  borderWidthBlockEnd: 'borderWidthBlockEnd',
  borderColor: ['borderColorInlineStart', 'borderColorInlineEnd', 'borderColorBlockStart', 'borderColorBlockEnd'],
  borderRadius: ['borderRadiusInlineStart', 'borderRadiusInlineEnd', 'borderRadiusBlockStart', 'borderRadiusBlockEnd'],
  borderRadiusInline: ['borderRadiusInlineStart', 'borderRadiusInlineEnd'],
  borderRadiusInlineStart: 'borderRadiusInlineStart',
  borderRadiusInlineEnd: 'borderRadiusInlineEnd',
  borderRadiusBlock: ['borderRadiusBlockStart', 'borderRadiusBlockEnd'],
  borderRadiusBlockStart: 'borderRadiusBlockStart',
  borderRadiusBlockEnd: 'borderRadiusBlockEnd',
  spacing: 'spacing',
  stack: 'stack'
};

function generateResponsiveClassnames(props, breakpoint) {
  return Object.entries(props).map(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        prop = _ref2[0],
        value = _ref2[1];

    return [prop, value == null ? value : "".concat(value)];
  }).filter(function (_ref3) {
    var _ref4 = _slicedToArray(_ref3, 2),
        prop = _ref4[0],
        value = _ref4[1];

    return classNamesMap[prop] && value;
  }).reduce(function (classNames, _ref5) {
    var _ref6 = _slicedToArray(_ref5, 2),
        prop = _ref6[0],
        value = _ref6[1];

    var property = classNamesMap[prop];

    if (Array.isArray(property)) {
      return [].concat(_toConsumableArray(classNames), _toConsumableArray(property.map(function (property) {
        return breakpoint && breakpoint !== 'base' ? (0, _cssUtilities.variationName)((0, _cssUtilities.variationName)(breakpoint, property), value) : (0, _cssUtilities.variationName)(property, value);
      })));
    }

    return [].concat(_toConsumableArray(classNames), [breakpoint && breakpoint !== 'base' ? (0, _cssUtilities.variationName)((0, _cssUtilities.variationName)(breakpoint, property), value) : (0, _cssUtilities.variationName)(property, value)]);
  }, []);
}

function convertLogicalProps(prop, value) {
  if (Array.isArray(value)) {
    if (value.length === 2) {
      var _ref7;

      var _value = _slicedToArray(value, 2),
          block = _value[0],
          inline = _value[1];

      return _ref7 = {}, _defineProperty(_ref7, "".concat(prop, "Block"), block), _defineProperty(_ref7, "".concat(prop, "Inline"), inline), _ref7;
    } else if (value.length === 4) {
      var _ref8;

      var _value2 = _slicedToArray(value, 4),
          blockStart = _value2[0],
          inlineEnd = _value2[1],
          blockEnd = _value2[2],
          inlineStart = _value2[3];

      return _ref8 = {}, _defineProperty(_ref8, "".concat(prop, "BlockStart"), blockStart), _defineProperty(_ref8, "".concat(prop, "InlineEnd"), inlineEnd), _defineProperty(_ref8, "".concat(prop, "BlockEnd"), blockEnd), _defineProperty(_ref8, "".concat(prop, "InlineStart"), inlineStart), _ref8;
    }
  }

  return _defineProperty({}, prop, value);
}

function useResponsive(props) {
  return Object.entries(props).reduce(function (classNames, _ref10) {
    var _ref11 = _slicedToArray(_ref10, 2),
        prop = _ref11[0],
        values = _ref11[1];

    if (Array.isArray(values) || _typeof(values) !== 'object') {
      return [].concat(_toConsumableArray(classNames), _toConsumableArray(generateResponsiveClassnames(convertLogicalProps(prop, values))));
    }

    return [].concat(_toConsumableArray(classNames), _toConsumableArray(Object.entries(values).map(function (_ref12) {
      var _ref13 = _slicedToArray(_ref12, 2),
          breakpoint = _ref13[0],
          value = _ref13[1];

      return generateResponsiveClassnames(convertLogicalProps(prop, value), breakpoint);
    }).reduce(function (classNames, className) {
      return classNames.concat(className);
    }, [])));
  }, []);
}