function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

import React, { createContext, useContext } from 'react';
import { classNames } from '@shopify/css-utilities';
import { CheckboxControl } from '../Checkbox';
import { RadioControl } from '../RadioControl';
import styles from './ChoiceList.css';
var ChoiceListContext = /*#__PURE__*/createContext(null);

function useChoiceList() {
  var context = useContext(ChoiceListContext);

  if (context == null) {
    throw new Error('No `ChoiceList` found in context');
  }

  return context;
}

// TODO: consider adding error prop
export function ChoiceList(_ref) {
  var name = _ref.name,
      value = _ref.value,
      onChange = _ref.onChange,
      children = _ref.children;

  var onChangeHandler = function onChangeHandler(id, checked) {
    onChange(getNewValue(value, checked, id));
  };

  return /*#__PURE__*/React.createElement(ChoiceListContext.Provider, {
    value: {
      name: name,
      value: value,
      onChangeHandler: onChangeHandler
    }
  }, children);
}
export function Choice(_ref2) {
  var id = _ref2.id,
      disabled = _ref2.disabled,
      accessibilityLabel = _ref2.accessibilityLabel,
      children = _ref2.children;

  var _useChoiceList = useChoiceList(),
      name = _useChoiceList.name,
      onChangeHandler = _useChoiceList.onChangeHandler,
      value = _useChoiceList.value;

  var Control = isString(value) ? RadioControl : CheckboxControl;
  var checked = isString(value) ? value === id : value.includes(id);
  var className = classNames(styles.Label, disabled && styles['Label-isDisabled']);
  return /*#__PURE__*/React.createElement("div", {
    className: styles.Wrapper
  }, /*#__PURE__*/React.createElement(Control, {
    id: id,
    name: name,
    disabled: disabled,
    checked: checked,
    onChange: function onChange(value) {
      onChangeHandler(id, value);
    }
  }), /*#__PURE__*/React.createElement("label", {
    htmlFor: id,
    className: className,
    "aria-label": accessibilityLabel ? accessibilityLabel : undefined
  }, children));
}

function getNewValue(value, checked, id) {
  if (checked === true) {
    return isString(value) ? id : [].concat(_toConsumableArray(value), [id]);
  }

  return isString(value) ? '' : value.filter(function (el) {
    return el !== id;
  });
}

function isString(value) {
  return typeof value === 'string';
}