import React, { useMemo } from 'react';
import { View } from '../View';
import { createIdCreator, useId } from '../../utilities/id';
import { FormContext, useContainingForm } from '../../utilities/forms';
import { Portal } from '../Portal';
import { useTranslate } from '../AppContext';
import styles from './Form.css';
var createId = createIdCreator('Form');
export function Form(_ref) {
  var onSubmit = _ref.onSubmit,
      children = _ref.children,
      _ref$implicitSubmit = _ref.implicitSubmit,
      implicitSubmit = _ref$implicitSubmit === void 0 ? true : _ref$implicitSubmit,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      id = _ref.id;
  var translate = useTranslate();
  var generatedId = useId(undefined, createId);
  var formId = id !== null && id !== void 0 ? id : generatedId;
  var nested = useContainingForm() != null;
  var formDetails = useMemo(function () {
    return {
      id: formId,
      nested: nested
    };
  }, [formId, nested]);
  var implicitSubmitContent = null;

  if (implicitSubmit) {
    implicitSubmitContent = /*#__PURE__*/React.createElement(View, {
      visibility: "hidden"
    }, /*#__PURE__*/React.createElement(ImplicitSubmitter, {
      disabled: disabled,
      form: formDetails
    }, typeof implicitSubmit === 'string' ? implicitSubmit : translate('submit')));
  }

  var handleSubmit = function handleSubmit(event) {
    event.preventDefault();
    event.stopPropagation();
    if (disabled) return;
    onSubmit();
  };

  return nested ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(FormContext.Provider, {
    value: formDetails
  }, children, implicitSubmitContent), /*#__PURE__*/React.createElement(Portal, null, /*#__PURE__*/React.createElement("form", {
    action: "",
    method: "POST",
    noValidate: true,
    className: styles.Form,
    id: formId,
    onSubmit: handleSubmit
  }))) : /*#__PURE__*/React.createElement("form", {
    action: "",
    method: "POST",
    noValidate: true,
    className: styles.Form,
    id: formId,
    onSubmit: handleSubmit
  }, /*#__PURE__*/React.createElement(FormContext.Provider, {
    value: formDetails
  }, children, implicitSubmitContent));
}

function ImplicitSubmitter(_ref2) {
  var form = _ref2.form,
      children = _ref2.children,
      disabled = _ref2.disabled;
  return /*#__PURE__*/React.createElement("button", {
    type: "submit",
    disabled: disabled,
    tabIndex: -1,
    "aria-hidden": true,
    form: form.nested ? form.id : undefined
  }, children);
}