import React from 'react';
import { classNames } from '@shopify/css-utilities';
import { useInlineFormatting } from '../../utilities/inlineFormatting';
import styles from './Hidden.css';
var VIEWPORT_SIZES = ['small', 'medium', 'large'];

/**
 * Hidden is used to hide content from users based on their viewport size.
 */
export function Hidden(_ref) {
  var above = _ref.above,
      below = _ref.below,
      children = _ref.children;
  var inline = useInlineFormatting();
  var Component = inline ? 'span' : 'div';

  var _getResponsiveValuesF = getResponsiveValuesFromRange(above, below),
      hiddenOnSmall = _getResponsiveValuesF.hiddenOnSmall,
      hiddenOnMedium = _getResponsiveValuesF.hiddenOnMedium,
      hiddenOnLarge = _getResponsiveValuesF.hiddenOnLarge;

  var className = classNames(styles.Hidden, hiddenOnSmall && styles.hiddenOnSmall, hiddenOnMedium && styles.hiddenOnMedium, hiddenOnLarge && styles.hiddenOnLarge);
  return /*#__PURE__*/React.createElement(Component, {
    className: className
  }, children);
}

function getResponsiveValuesFromRange(above, below) {
  if (above === below) {
    return {
      hiddenOnSmall: true,
      hiddenOnMedium: false,
      hiddenOnLarge: true
    };
  }

  var start = above ? VIEWPORT_SIZES.indexOf(above) + 1 : 0;
  var end = below ? VIEWPORT_SIZES.indexOf(below) - 1 : VIEWPORT_SIZES.length - 1;
  var range = VIEWPORT_SIZES.slice(start, end + 1);
  var hiddenOnSmall = range.indexOf('small') >= 0;
  var hiddenOnMedium = range.indexOf('medium') >= 0;
  var hiddenOnLarge = range.indexOf('large') >= 0;
  return {
    hiddenOnSmall: hiddenOnSmall,
    hiddenOnMedium: hiddenOnMedium,
    hiddenOnLarge: hiddenOnLarge
  };
}