import React from 'react';
import { mountWithContext } from '../../test-utilities';
import { TextBlock } from '../TextBlock';
import { Hidden } from './Hidden';
describe('<Hidden />', function () {
  it('renders its children', function () {
    var text = 'Snowdevil';
    var hidden = mountWithContext( /*#__PURE__*/React.createElement(Hidden, {
      below: "medium"
    }, text));
    expect(hidden).toContainReactText(text);
  });
  it('renders a <div> by default', function () {
    var text = 'Snowdevil';
    var hidden = mountWithContext( /*#__PURE__*/React.createElement(Hidden, {
      below: "medium"
    }, text));
    expect(hidden).toContainReactComponent('div');
  });
  it('renders a <span> when used inside an inline formatting context', function () {
    var text = 'Snowdevil';
    var hiddenTextBlock = mountWithContext( /*#__PURE__*/React.createElement(TextBlock, null, /*#__PURE__*/React.createElement(Hidden, {
      below: "medium"
    }, text)));
    expect(hiddenTextBlock).toContainReactComponent('span');
  });
  describe('above', function () {
    it('applies CSS classes that hides the element above the specified breakpoint', function () {
      var text = 'Snowdevil';
      var hiddenAboveSmall = mountWithContext( /*#__PURE__*/React.createElement(Hidden, {
        above: "small"
      }, text));
      var hiddenAboveMedium = mountWithContext( /*#__PURE__*/React.createElement(Hidden, {
        above: "medium"
      }, text));
      expect(hiddenAboveSmall).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnMedium hiddenOnLarge')
      });
      expect(hiddenAboveMedium).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnLarge')
      });
    });
  });
  describe('below', function () {
    it('applies CSS classes that hides the element below the specified breakpoint', function () {
      var text = 'Snowdevil';
      var hiddenBelowMedium = mountWithContext( /*#__PURE__*/React.createElement(Hidden, {
        below: "medium"
      }, text));
      var hiddenBelowLarge = mountWithContext( /*#__PURE__*/React.createElement(Hidden, {
        below: "large"
      }, text));
      expect(hiddenBelowMedium).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnSmall')
      });
      expect(hiddenBelowLarge).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnSmall hiddenOnMedium')
      });
    });
  });
  describe('below and above combined', function () {
    it('applies CSS classes that hides the element when both below and above is specified', function () {
      var text = 'Snowdevil';
      var hiddenBelowLargeAboveSmall = mountWithContext( /*#__PURE__*/React.createElement(Hidden, {
        above: "small",
        below: "large"
      }, text));
      var hiddenBelowMediumAboveMedium = mountWithContext( /*#__PURE__*/React.createElement(Hidden, {
        above: "medium",
        below: "medium"
      }, text));
      expect(hiddenBelowLargeAboveSmall).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnMedium')
      });
      expect(hiddenBelowMediumAboveMedium).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnSmall hiddenOnLarge')
      });
    });
  });
});