import React from 'react';
import { mount } from '@quilted/react-testing/dom';
import faker from 'faker';
import { View } from '../View';
import { Image, MEDIA_MAP } from './Image';
describe('<Image />', function () {
  var source = faker.image.imageUrl();
  describe('sources', function () {
    it('renders a picture element with sources with an img fallback', function () {
      var description = faker.random.words();
      var image = mount( /*#__PURE__*/React.createElement(Image, {
        source: source,
        sources: [{
          source: source
        }],
        description: description,
        loading: "lazy"
      }));
      expect(image).toContainReactComponent('picture');
      expect(image).toContainReactComponent('source', {
        srcSet: source
      });
      expect(image).toContainReactComponent('img', {
        src: source,
        alt: description,
        loading: 'lazy'
      });
    });
    it('reduces multiple sources with the same viewportSize into a single srcSet', function () {
      var image = mount( /*#__PURE__*/React.createElement(Image, {
        source: source,
        sources: [{
          source: source,
          viewportSize: 'small',
          resolution: 1
        }, {
          source: source,
          viewportSize: 'small',
          resolution: 2
        }],
        loading: "lazy"
      }));
      expect(image).toContainReactComponent('source', {
        srcSet: "".concat(source, " 1x, ").concat(source, " 2x"),
        media: MEDIA_MAP.get('small')
      });
    });
    it('renders an img element only when no sources are provided', function () {
      var image = mount( /*#__PURE__*/React.createElement(Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent('picture');
      expect(image).not.toContainReactComponent('source');
      expect(image).toContainReactComponent('img', {
        src: source
      });
    });
  });
  describe('decorative', function () {
    it('wraps the image with <View accessibilityVisibility="hidden" />', function () {
      var image = mount( /*#__PURE__*/React.createElement(Image, {
        source: source,
        decorative: true
      }));
      expect(image).toContainReactComponent(View, {
        accessibilityVisibility: 'hidden'
      });
    });
    it('by default the image is not wrapped with <View accessibilityVisibility="hidden" />', function () {
      var image = mount( /*#__PURE__*/React.createElement(Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent(View, {
        accessibilityVisibility: 'hidden'
      });
    });
  });
  describe('aspectRatio', function () {
    it('wraps the image with placeholder container', function () {
      var image = mount( /*#__PURE__*/React.createElement(Image, {
        source: source,
        aspectRatio: 16 / 9
      }));
      expect(image).toContainReactComponent('div', {
        style: {
          paddingBottom: "calc(100% / ".concat(16 / 9, ")")
        }
      });
    });
    it('by default the image does not have any container', function () {
      var image = mount( /*#__PURE__*/React.createElement(Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent('div');
    });
  });
});