function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../../../test-utilities';
import { CheckboxControl } from '../../../Checkbox';
import { RadioControl } from '../../../RadioControl';
import { View } from '../../../View';
import { OptionList } from '../../OptionList';
import { Option } from './Option';
var defaultProps = {
  id: faker.random.uuid(),
  label: faker.random.word()
};
var defaultOptionListProps = {
  id: faker.random.uuid(),
  selectedItems: [],
  onChange: function onChange() {
    return null;
  },
  children: /*#__PURE__*/React.createElement("div", null)
};
describe('<Option />', function () {
  it('triggers onChange when input is selected', function () {
    var id = faker.random.uuid();
    var onChangeSpy = jest.fn();
    var optionList = mountWithContext( /*#__PURE__*/React.createElement(OptionList, Object.assign({}, defaultOptionListProps, {
      onChange: onChangeSpy
    }), /*#__PURE__*/React.createElement(Option, Object.assign({}, defaultProps, {
      id: id
    }))));
    optionList.find(Option).find(RadioControl).trigger('onChange');
    expect(onChangeSpy).toHaveBeenCalledWith([id]);
  });
  it('input is active if selected', function () {
    var id = faker.random.uuid();
    var optionList = mountWithContext( /*#__PURE__*/React.createElement(OptionList, Object.assign({}, defaultOptionListProps, {
      selectedItems: [id]
    }), /*#__PURE__*/React.createElement(Option, Object.assign({}, defaultProps, {
      id: id
    }))));
    expect(optionList.find(Option)).toContainReactComponent('input', {
      checked: true
    });
  });
  it('renders a RadioControl if allow multiple is false', function () {
    var optionList = mountWithContext( /*#__PURE__*/React.createElement(OptionList, defaultOptionListProps, /*#__PURE__*/React.createElement(Option, defaultProps)));
    expect(optionList.find(Option)).toContainReactComponent(RadioControl);
  });
  it('renders a CheckboxControl if allow multiple is true', function () {
    var optionList = mountWithContext( /*#__PURE__*/React.createElement(OptionList, Object.assign({}, defaultOptionListProps, {
      allowMultiple: true
    }), /*#__PURE__*/React.createElement(Option, defaultProps)));
    expect(optionList.find(Option)).toContainReactComponent(CheckboxControl);
  });
  it('renders visually hidden View when label and childrens are set', function () {
    var labelContent = faker.random.word();
    var optionList = mountWithContext( /*#__PURE__*/React.createElement(OptionList, defaultOptionListProps, /*#__PURE__*/React.createElement(Option, Object.assign({}, defaultProps, {
      label: labelContent
    }), "Childrens")));
    expect(optionList.find(View, {
      visibility: 'hidden'
    })).toContainReactText(labelContent);
  });
  describe('allowMultiple', function () {
    it('allows the selection of multiple options', function () {
      var firstItem = faker.random.uuid();
      var secondItem = faker.random.uuid();
      var optionList = mountWithContext( /*#__PURE__*/React.createElement(OptionList, Object.assign({}, defaultOptionListProps, {
        allowMultiple: true,
        selectedItems: [firstItem, secondItem]
      }), /*#__PURE__*/React.createElement(Option, Object.assign({}, defaultProps, {
        id: firstItem
      })), /*#__PURE__*/React.createElement(Option, Object.assign({}, defaultProps, {
        id: secondItem
      }))));

      var _optionList$findAll = optionList.findAll(Option),
          _optionList$findAll2 = _slicedToArray(_optionList$findAll, 2),
          firstOption = _optionList$findAll2[0],
          secondOption = _optionList$findAll2[1];

      expect(firstOption).toContainReactComponent(CheckboxControl, {
        checked: true
      });
      expect(secondOption).toContainReactComponent(CheckboxControl, {
        checked: true
      });
    });
    it('toggles the selection of already selection options', function () {
      var selected = faker.random.uuid();
      var onChangeSpy = jest.fn();
      var optionList = mountWithContext( /*#__PURE__*/React.createElement(OptionList, Object.assign({}, defaultOptionListProps, {
        allowMultiple: true,
        selectedItems: [selected],
        onChange: onChangeSpy
      }), /*#__PURE__*/React.createElement(Option, Object.assign({}, defaultProps, {
        id: selected
      }))));
      optionList.find(Option).find(CheckboxControl).trigger('onChange');
      expect(onChangeSpy).toHaveBeenCalledWith([]);
    });
  });
  describe('controlHidden', function () {
    it('shows control by default', function () {
      var optionList = mountWithContext( /*#__PURE__*/React.createElement(OptionList, defaultOptionListProps, /*#__PURE__*/React.createElement(Option, defaultProps)));
      expect(optionList.find(Option)).toContainReactComponent(RadioControl);
    });
    it('hides control when true', function () {
      var optionList = mountWithContext( /*#__PURE__*/React.createElement(OptionList, Object.assign({}, defaultOptionListProps, {
        controlHidden: true
      }), /*#__PURE__*/React.createElement(Option, defaultProps)));
      expect(optionList.find(Option)).not.toContainReactComponent(RadioControl);
    });
  });
});