import React from 'react';
import { mountWithContext } from '../../test-utilities';
import { RadioControl } from './RadioControl';
var defaultProps = {
  name: 'radio_button'
};
describe('<RadioControl />', function () {
  it('renders an un-checked radio', function () {
    var radio = mountWithContext( /*#__PURE__*/React.createElement(RadioControl, defaultProps));
    expect(radio).toContainReactComponent('input', {
      checked: false,
      type: 'radio'
    });
  });
  it('renders a checked radio when the checked prop is provided and set to true', function () {
    var radio = mountWithContext( /*#__PURE__*/React.createElement(RadioControl, Object.assign({}, defaultProps, {
      checked: true
    })));
    expect(radio).toContainReactComponent('input', {
      checked: true,
      type: 'radio'
    });
  });
  it('renders a checked radio when the value prop is provided and set to true', function () {
    var radio = mountWithContext( /*#__PURE__*/React.createElement(RadioControl, Object.assign({}, defaultProps, {
      value: true
    })));
    expect(radio).toContainReactComponent('input', {
      checked: true,
      type: 'radio'
    });
  });
  it('renders a disabled radio when the disabled prop is provided and set to true', function () {
    var radio = mountWithContext( /*#__PURE__*/React.createElement(RadioControl, Object.assign({}, defaultProps, {
      disabled: true
    })));
    expect(radio).toContainReactComponent('input', {
      disabled: true,
      type: 'radio'
    });
  });
  it('calls the onChange callback when the radio is checked and unchecked', function () {
    var onChangeSpy = jest.fn();
    var radio = mountWithContext( /*#__PURE__*/React.createElement(RadioControl, Object.assign({}, defaultProps, {
      onChange: onChangeSpy
    })));
    radio.find('input').trigger('onChange', {
      currentTarget: {
        checked: true
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(true);
    radio.find('input').trigger('onChange', {
      currentTarget: {
        checked: false
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(false);
  });
});