import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../test-utilities';
import { Icon } from '../Icon';
import { Thumbnail } from '.';
var defaultProps = {
  description: faker.lorem.words(2)
};
describe('<Thumbnail />', function () {
  describe('badge', function () {
    it('renders a badge when provided as a string', function () {
      var badge = 'New';
      var thumbnail = mountWithContext( /*#__PURE__*/React.createElement(Thumbnail, Object.assign({}, defaultProps, {
        badge: badge
      })));
      expect(thumbnail).toContainReactComponent('span', {
        children: badge
      });
    });
    it('renders a badge when provided as a number', function () {
      var badge = 1;
      var thumbnail = mountWithContext( /*#__PURE__*/React.createElement(Thumbnail, Object.assign({}, defaultProps, {
        badge: badge
      })));
      expect(thumbnail).toContainReactComponent('span', {
        children: badge
      });
    });
  });
  describe('source & description', function () {
    it('renders an <img /> with a src and alt when provided with source and description', function () {
      var source = faker.internet.url();
      var description = faker.lorem.words(2);
      var thumbnail = mountWithContext( /*#__PURE__*/React.createElement(Thumbnail, {
        source: source,
        description: description
      }));
      expect(thumbnail).toContainReactComponent('img', {
        src: source,
        alt: description
      });
    });
    it('renders a placeholder Icon if source is not provided', function () {
      var thumbnail = mountWithContext( /*#__PURE__*/React.createElement(Thumbnail, defaultProps));
      expect(thumbnail).toContainReactComponent(Icon, {
        source: 'camera'
      });
    });
  });
  describe('sources', function () {
    it('renders a <img /> with srcset when provided with sources', function () {
      var source = faker.internet.url();
      var sources = ["".concat(faker.internet.url(), " 1x"), "".concat(faker.internet.url(), " 2x"), "".concat(faker.internet.url(), " 3x")];
      var thumbnail = mountWithContext( /*#__PURE__*/React.createElement(Thumbnail, Object.assign({}, defaultProps, {
        source: source,
        sources: sources
      })));
      expect(thumbnail).toContainReactComponent('img', {
        srcSet: sources.join(', ')
      });
    });
    it('does not render a <img /> with srcset if sources are undefined', function () {
      var thumbnail = mountWithContext( /*#__PURE__*/React.createElement(Thumbnail, defaultProps));
      expect(thumbnail).not.toContainReactComponent('img', {
        srcSet: expect.anything()
      });
    });
  });
});