import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../test-utilities';
import { ToggleButton, ToggleButtonGroup } from './index';
var defaultProps = {
  id: faker.random.uuid(),
  selectedItem: faker.random.uuid(),
  onChange: function onChange() {
    return null;
  }
};
describe('<ToggleButton />', function () {
  it('renders its children', function () {
    var id = faker.random.uuid();

    function Children() {
      return /*#__PURE__*/React.createElement("div", null, "children");
    }

    var toggleButtonGroup = mountWithContext( /*#__PURE__*/React.createElement(ToggleButtonGroup, defaultProps, /*#__PURE__*/React.createElement(ToggleButton, {
      id: id
    }, /*#__PURE__*/React.createElement(Children, null))));
    expect(toggleButtonGroup).toContainReactComponent(Children);
  });
  describe('onChange', function () {
    it('triggers onChange when button is selected', function () {
      var id = faker.random.uuid();
      var onChangeSpy = jest.fn();
      var toggleButtonGroup = mountWithContext( /*#__PURE__*/React.createElement(ToggleButtonGroup, Object.assign({}, defaultProps, {
        onChange: onChangeSpy
      }), /*#__PURE__*/React.createElement(ToggleButton, {
        id: id
      })));
      toggleButtonGroup.find('button').trigger('onClick');
      expect(onChangeSpy).toHaveBeenCalledWith(id);
    });
  });
  describe('aria-pressed', function () {
    it('aria-pressed corresponds to not selected', function () {
      var id = faker.random.uuid();
      var toggleButtonGroup = mountWithContext( /*#__PURE__*/React.createElement(ToggleButtonGroup, defaultProps, /*#__PURE__*/React.createElement(ToggleButton, {
        id: id
      })));
      expect(toggleButtonGroup).toContainReactComponent('button', {
        'aria-pressed': false
      });
    });
    it('aria-pressed corresponds to selected', function () {
      var id = faker.random.uuid();
      var toggleButtonGroup = mountWithContext( /*#__PURE__*/React.createElement(ToggleButtonGroup, Object.assign({}, defaultProps, {
        selectedItem: id
      }), /*#__PURE__*/React.createElement(ToggleButton, {
        id: id
      })));
      expect(toggleButtonGroup).toContainReactComponent('button', {
        'aria-pressed': true
      });
    });
  });
});