import React from 'react';
import { mount } from '@quilted/react-testing/dom';
import { View } from './View';
describe('<View />', function () {
  describe('children', function () {
    it('renders its children', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, null, text, " "));
      expect(view).toContainReactText(text);
    });
  });
  describe('display', function () {
    it('renders a div by default', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, null, text, " "));
      expect(view).toContainReactComponent('div');
    });
    it('renders a span when "inline" is set', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, {
        display: "inline"
      }, text, " "));
      expect(view).toContainReactComponent('span');
    });
    it('renders a div when "block" is set', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, {
        display: "block"
      }, text, " "));
      expect(view).toContainReactComponent('div');
    });
  });
  describe('accessibilityVisibility', function () {
    it('sets aria-hidden to true when accessibilityVisibility is set', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, {
        accessibilityVisibility: "hidden"
      }, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': true
      });
    });
    it('sets aria-hidden to false when accessibilityVisibility is not set', function () {
      var text = 'Snowdevil';
      var view = mount( /*#__PURE__*/React.createElement(View, null, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': false
      });
    });
  });
});