import React, { useEffect } from 'react';
import { matchMedia } from '@shopify/jest-dom-mocks';
import { mountWithContext } from '../test-utilities';
import { createMediaQueries, useBreakpoint } from './breakpoint';
describe('createMediaQueries', function () {
  it('creates media queries', function () {
    var mediaQueries = createMediaQueries();
    expect(mediaQueries).toStrictEqual([{
      breakpoint: 'base',
      query: '(min-width: 0px) and (max-width: 749px)'
    }, {
      breakpoint: 'small',
      query: '(min-width: 750px) and (max-width: 999px)'
    }, {
      breakpoint: 'medium',
      query: '(min-width: 1000px) and (max-width: 1199px)'
    }, {
      breakpoint: 'large',
      query: '(min-width: 1200px)'
    }]);
  });
});
describe('useBreakpoint', function () {
  var spy = jest.fn();

  function Component() {
    var breakpoint = useBreakpoint();
    useEffect(function () {
      spy(breakpoint);
    });
    return null;
  }

  beforeEach(function () {
    matchMedia.mock();
  });
  afterEach(function () {
    matchMedia.restore();
    spy.mockReset();
  });
  it('does not match any breakpoint', function () {
    matchMedia.setMedia(function () {
      return {
        matches: false
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([[undefined]]);
  });
  it('matches base breakpoint', function () {
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 0px) and (max-width: 749px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['base']]);
  });
  it('matches small breakpoint', function () {
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 750px) and (max-width: 999px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['small']]);
  });
  it('matches medium breakpoint', function () {
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1000px) and (max-width: 1199px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['medium']]);
  });
  it('matches large breakpoint', function () {
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1200px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['large']]);
  });
});