import React, { useEffect } from 'react';
import { matchMedia } from '@shopify/jest-dom-mocks';
import { mountWithContext } from '../test-utilities';
import { useResponsiveValue } from './responsiveValue';
describe('useResponsiveValue', function () {
  var spy = jest.fn();

  function Component(_ref) {
    var values = _ref.values;
    var value = useResponsiveValue(values);
    useEffect(function () {
      spy(value);
    });
    return null;
  }

  beforeEach(function () {
    matchMedia.mock();
  });
  afterEach(function () {
    matchMedia.restore();
    spy.mockReset();
  });
  it('returns undefined if no breakpoint matches', function () {
    var values = {
      small: 'small'
    };
    matchMedia.setMedia(function () {
      return {
        matches: false
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[undefined]]);
  });
  it('returns base value if it maches base breakpoint', function () {
    var values = {
      base: 'base'
    };
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 0px) and (max-width: 749px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.base]]);
  });
  it('returns small value if it maches small breakpoint', function () {
    var values = {
      small: 'small'
    };
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 750px) and (max-width: 999px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.small]]);
  });
  it('returns medium value if it maches medium breakpoint', function () {
    var values = {
      medium: 'medium'
    };
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1000px) and (max-width: 1199px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.medium]]);
  });
  it('returns large value if it maches large breakpoint', function () {
    var values = {
      large: 'large'
    };
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1200px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.large]]);
  });
  it('returns closest value if no breakpoint matches', function () {
    var values = {
      small: 'small',
      large: 'large'
    };
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 750px) and (max-width: 999px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.small]]);
  });
  it('returns closest non undefined value', function () {
    var values = {
      small: 'small',
      medium: null,
      large: undefined
    };
    matchMedia.setMedia(function (query) {
      return {
        matches: query === '(min-width: 1200px)'
      };
    });
    mountWithContext( /*#__PURE__*/React.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.medium]]);
  });
});