"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Button = void 0;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _forms = require("../../utilities/forms");

var _AppContext = require("../AppContext");

var _transition = require("../../utilities/transition");

var _Spinner = require("../Spinner");

var _Link = require("../Link");

var _legacy = require("../../utilities/legacy");

var _mediaQuery = require("../../utilities/media-query");

var _Connected = require("../Connected");

var _Theme = require("../Theme");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Button = _interopRequireDefault(require("./Button.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Button = /*#__PURE__*/(0, _react.forwardRef)(function Button({
  children,
  submit = false,
  disabled,
  onPress,
  to,
  subdued,
  plain,
  secondary,
  tertiary,
  loading = false,
  fill = false,
  loadingLabel,
  accessibilityLabel,
  underline,
  appearance,
  onMouseEnter
}, ref) {
  const href = disabled ? undefined : to;
  const onClick = disabled ? undefined : () => onPress === null || onPress === void 0 ? void 0 : onPress();
  const refsSetter = (0, _react.useCallback)(instance => {
    if (typeof ref === 'function') {
      ref(instance);
    } else if (ref) {
      ref.current = instance;
    }
  }, [ref]);
  const translate = (0, _AppContext.useTranslate)();
  const prefersReducedMotion = (0, _mediaQuery.usePrefersReducedMotion)();
  const transition = (0, _transition.useTransition)(loading, {
    enter: 'slow'
  });
  const connected = (0, _Connected.useConnected)();
  const {
    primaryButton: {
      typographyStyle: primaryStyle,
      loadingStyle: primaryLoading = 'spinner'
    },
    secondaryButton: {
      typographyStyle: secondaryStyle,
      loadingStyle: secondaryLoading = 'spinner'
    },
    link: {
      colorHovered,
      colorPressed
    }
  } = (0, _Theme.useThemeConfiguration)();
  const form = (0, _forms.useContainingForm)();
  const loadingStyle = secondary ? secondaryLoading : primaryLoading;
  const classes = (0, _cssUtilities.classNames)(_Button.default.Button, _legacy.button, subdued && !plain && _Button.default.subdued, plain && _Button.default.plain, plain && (appearance === 'inheritColor' ? _Button.default.appearanceInheritColor : _Button.default.appearanceDefault), plain && colorHovered && _Button.default[(0, _cssUtilities.variationName)('colorHovered', colorHovered)], plain && colorPressed && _Button.default[(0, _cssUtilities.variationName)('colorPressed', colorPressed)], plain && underline && _Button.default.underline, plain && appearance === 'inheritColor' && _Button.default.underline, disabled && _Button.default.disabled, loading && loadingStyle === 'spinner' && _Button.default.loading, fill && _Button.default.fill, loading && loadingStyle === 'spinner' && _Button.default[(0, _cssUtilities.variationName)('loading-transition', transition)], connected && _Button.default.connected, secondary && _Button.default.secondary, tertiary && _Button.default.tertiary, loading && loadingStyle === 'progressBar' && _Button.default[loadingStyle]);
  const normalizedLoadingLabel = loadingLabel ? loadingLabel : translate('processing');
  const contentTypography = secondary ? secondaryStyle && _typographyStyles.default[secondaryStyle] : primaryStyle && _typographyStyles.default[primaryStyle];
  const contentClassNames = (0, _cssUtilities.classNames)(_Button.default.Content, !plain && contentTypography);

  const content = /*#__PURE__*/_react.default.createElement("span", {
    className: contentClassNames
  }, loading && loadingStyle === 'progressBar' && prefersReducedMotion ? normalizedLoadingLabel : children);

  const type = submit ? 'submit' : 'button';

  const loadingMarkup = /*#__PURE__*/_react.default.createElement("span", {
    className: (0, _cssUtilities.classNames)(_Button.default.LoadingContent, !prefersReducedMotion && _Button.default.Spinner)
  }, /*#__PURE__*/_react.default.createElement(_Spinner.Spinner, {
    size: "small",
    color: "inherit",
    accessibilityLabel: normalizedLoadingLabel
  }));

  if (href) {
    return /*#__PURE__*/_react.default.createElement(_Link.UnstyledLink, {
      to: href,
      className: classes,
      onPress: onPress,
      ariaBusy: loading,
      ariaLive: loading ? 'assertive' : 'polite',
      ariaLabel: accessibilityLabel
    }, content, loading && loadingStyle === 'spinner' && loadingMarkup);
  }

  return /*#__PURE__*/_react.default.createElement("button", {
    type: type,
    form: submit && (form === null || form === void 0 ? void 0 : form.nested) ? form.id : undefined,
    className: classes,
    disabled: disabled || loading,
    onClick: onClick,
    "aria-busy": loading,
    "aria-live": loading ? 'assertive' : undefined,
    "aria-label": accessibilityLabel,
    ref: refsSetter,
    onMouseEnter: onMouseEnter
  }, content, loading && loadingStyle === 'spinner' && loadingMarkup);
});
exports.Button = Button;