"use strict";

var _react = _interopRequireDefault(require("react"));

var _jestDomMocks = require("@shopify/jest-dom-mocks");

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _Link = require("../Link");

var _Spinner = require("../Spinner");

var _Form = require("../Form");

var _Button = require("./Button");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  children: 'Go to next step'
};
describe('<Button />', () => {
  beforeEach(() => {
    _jestDomMocks.matchMedia.mock();
  });
  afterEach(() => {
    _jestDomMocks.matchMedia.restore();
  });
  describe('`<button />`', () => {
    describe('children', () => {
      it('renders the children into the button', () => {
        const text = 'Go to shipping';
        const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, null, text));
        expect(button).toContainReactText(text);
      });
      it('renders the children into the link', () => {
        const text = 'Go to shipping';
        const linkButton = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, {
          to: "/shipping"
        }, text));
        expect(linkButton).toContainReactText(text);
      });
    });
    describe('onPress()', () => {
      it('is called when button is pressed', () => {
        const onPressSpy = jest.fn();
        const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
          onPress: onPressSpy
        })));
        button.find('button').trigger('onClick');
        expect(onPressSpy).toHaveBeenCalledTimes(1);
      });
    });
  });
  describe('`<UnstyledLink />`', () => {
    it('renders when a url is provided', () => {
      const url = '/shipping';
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        to: url
      })));
      expect(button).toContainReactComponent(_Link.UnstyledLink, {
        to: url
      });
    });
    it('renders a button when disabled', () => {
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        disabled: true,
        to: "/shipping"
      })));
      expect(button).not.toContainReactComponent(_Link.UnstyledLink);
      expect(button).toContainReactComponent('button', {
        disabled: true
      });
    });
  });
  describe('submit', () => {
    it('renders a type button when not present', () => {
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, defaultProps));
      expect(button).toContainReactComponent('button', {
        type: 'button'
      });
    });
    it('renders a type submit when present', () => {
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        submit: true
      })));
      expect(button).toContainReactComponent('button', {
        type: 'submit'
      });
    });
    it('renders a form id when rendered in a nested form', () => {
      const testId = _faker.default.random.word();

      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Form.Form, {
        onSubmit: noop
      }, /*#__PURE__*/_react.default.createElement(_Form.Form, {
        id: testId,
        onSubmit: noop
      }, /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        submit: true
      })))));
      expect(button).toContainReactComponent('button', {
        type: 'submit',
        form: testId
      });
    });
    it('does not render a form id when rendered in a non-nested form', () => {
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Form.Form, {
        onSubmit: noop
      }, /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        submit: true
      }))));
      expect(button).toContainReactComponent('button', {
        type: 'submit',
        form: undefined
      });
    });
  });
  describe('loading', () => {
    it('disables button when loading', () => {
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent('button', {
        disabled: true
      });
    });
    it('indicates that the button is getting updated', () => {
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent('button', {
        'aria-busy': true
      });
      const unstyledLink = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true,
        to: "/shipping"
      })));
      expect(unstyledLink).toContainReactComponent(_Link.UnstyledLink, {
        ariaBusy: true
      });
    });
    it('sets the right priority of announcement for screen readers', () => {
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent('button', {
        'aria-live': 'assertive'
      });
      const unstyledLink = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true,
        to: "/shipping"
      })));
      expect(unstyledLink).toContainReactComponent(_Link.UnstyledLink, {
        ariaLive: 'assertive'
      });
    });
    it('renders a <Spinner> when loading', () => {
      _jestDomMocks.matchMedia.setMedia(() => ({
        matches: false
      }));

      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent(_Spinner.Spinner);
    });
    it('renders the loadingLabel as the Spinner children when provided', () => {
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        loadingLabel: "Processing",
        loading: true
      })));
      expect(button).toContainReactComponent(_Spinner.Spinner, {
        accessibilityLabel: 'Processing'
      });
    });
    it('adds the Spinner class when user does not prefers reduced motion', () => {
      _jestDomMocks.matchMedia.setMedia(() => ({
        matches: false
      }));

      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        loadingLabel: "Processing",
        loading: true
      })));
      expect(button).toContainReactComponent('span', {
        className: 'LoadingContent Spinner'
      });
    });
    it('removes the Spinner class when user prefers reduced motion', () => {
      _jestDomMocks.matchMedia.setMedia(() => ({
        matches: true
      }));

      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        loadingLabel: "Processing",
        loading: true
      })));
      expect(button).not.toContainReactComponent('span', {
        className: 'LoadingContent Spinner'
      });
    });
  });
  describe('accessibilityLabel', () => {
    it('renders an accessible label when provided', () => {
      const content = 'Accessible label';
      const button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        accessibilityLabel: content
      })));
      expect(button).toContainReactComponent('button', {
        'aria-label': content
      });
      const unstyledLink = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Button.Button, Object.assign({}, defaultProps, {
        accessibilityLabel: content,
        to: "/shipping"
      })));
      expect(unstyledLink).toContainReactComponent(_Link.UnstyledLink, {
        ariaLabel: content
      });
    });
  });
});

function noop() {}