"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Checkbox = Checkbox;
exports.CheckboxControl = CheckboxControl;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Icon = require("../Icon");

var _InlineError = require("../InlineError");

var _Theme = require("../Theme");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _Checkbox = _interopRequireDefault(require("./Checkbox.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createId = (0, _id.createIdCreator)('Checkbox');

function Checkbox({
  id: explicitId,
  name,
  accessibilityLabel,
  error,
  disabled,
  children,
  ...rest
}) {
  const id = (0, _id.useId)(explicitId, createId);
  const {
    checkbox: {
      errorIndentation,
      errorTypographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  const errorMarkup = error ? /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Checkbox.default.Error, errorTypographyStyle && _typographyStyles.default[errorTypographyStyle])
  }, /*#__PURE__*/_react.default.createElement(_InlineError.InlineError, {
    controlID: id
  }, error)) : null;
  const labelClassName = (0, _cssUtilities.classNames)(_Checkbox.default.Label, disabled && _Checkbox.default['Label-isDisabled']);
  const hasError = Boolean(error);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Checkbox.default.Wrapper, hasError && _Checkbox.default.hasError, hasError && errorIndentation && _Checkbox.default[(0, _cssUtilities.variationName)('errorIndentation', errorIndentation)])
  }, /*#__PURE__*/_react.default.createElement(CheckboxControl, Object.assign({
    id: id,
    name: name,
    error: Boolean(error),
    disabled: disabled
  }, rest)), /*#__PURE__*/_react.default.createElement("label", {
    htmlFor: id,
    className: labelClassName,
    "aria-label": accessibilityLabel ? accessibilityLabel : undefined
  }, children), errorMarkup);
}

function CheckboxControl({
  id,
  name,
  value = false,
  checked = value,
  disabled,
  error = false,
  onChange
}) {
  const {
    controls: {
      background: controlsBackground
    },
    checkbox: {
      background: checkboxBackground,
      borderColor = 'base'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const background = checkboxBackground || controlsBackground || 'surfaceTertiary';
  const className = (0, _cssUtilities.classNames)(_Checkbox.default.Input, error && _Checkbox.default['Input-hasError'], disabled && _Checkbox.default['Input-isDisabled'], _Checkbox.default[(0, _cssUtilities.variationName)('Input-background', background)], _Checkbox.default[(0, _cssUtilities.variationName)('Input-borderColor', borderColor)]);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Checkbox.default.Checkbox
  }, /*#__PURE__*/_react.default.createElement("input", {
    type: "checkbox",
    id: id,
    name: name,
    checked: checked,
    disabled: disabled,
    onChange: ({
      currentTarget
    }) => {
      onChange === null || onChange === void 0 ? void 0 : onChange(currentTarget.checked);
    },
    className: className,
    "aria-describedby": error ? (0, _errors.errorId)(id) : undefined,
    "aria-invalid": error
  }), /*#__PURE__*/_react.default.createElement("div", {
    className: _Checkbox.default.Icon
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "checkmark",
    size: "small"
  })));
}