"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ChoiceList = ChoiceList;
exports.Choice = Choice;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Checkbox = require("../Checkbox");

var _RadioControl = require("../RadioControl");

var _ChoiceList = _interopRequireDefault(require("./ChoiceList.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const ChoiceListContext = /*#__PURE__*/(0, _react.createContext)(null);

function useChoiceList() {
  const context = (0, _react.useContext)(ChoiceListContext);

  if (context == null) {
    throw new Error('No `ChoiceList` found in context');
  }

  return context;
}

// TODO: consider adding error prop
function ChoiceList({
  name,
  value,
  onChange,
  children
}) {
  const onChangeHandler = (id, checked) => {
    onChange(getNewValue(value, checked, id));
  };

  return /*#__PURE__*/_react.default.createElement(ChoiceListContext.Provider, {
    value: {
      name,
      value,
      onChangeHandler
    }
  }, children);
}

function Choice({
  id,
  disabled,
  accessibilityLabel,
  children
}) {
  const {
    name,
    onChangeHandler,
    value
  } = useChoiceList();
  const Control = isString(value) ? _RadioControl.RadioControl : _Checkbox.CheckboxControl;
  const checked = isString(value) ? value === id : value.includes(id);
  const className = (0, _cssUtilities.classNames)(_ChoiceList.default.Label, disabled && _ChoiceList.default['Label-isDisabled']);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _ChoiceList.default.Wrapper
  }, /*#__PURE__*/_react.default.createElement(Control, {
    id: id,
    name: name,
    disabled: disabled,
    checked: checked,
    onChange: value => {
      onChangeHandler(id, value);
    }
  }), /*#__PURE__*/_react.default.createElement("label", {
    htmlFor: id,
    className: className,
    "aria-label": accessibilityLabel ? accessibilityLabel : undefined
  }, children));
}

function getNewValue(value, checked, id) {
  if (checked === true) {
    return isString(value) ? id : [...value, id];
  }

  return isString(value) ? '' : value.filter(el => el !== id);
}

function isString(value) {
  return typeof value === 'string';
}