"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _Checkbox = require("../Checkbox");

var _RadioControl = require("../RadioControl");

var _ChoiceList = require("./ChoiceList");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  name: 'choice_list'
};
const id = '123';
const singleValue = id;
const multiValue = [id];
const labelContent = 'Label content';
const accessibilityLabel = 'Accessibility label content';
describe('<ChoiceList />', () => {
  it('renders a `RadioControl` component as the `Choice` when `value` is a single string', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList).toContainReactComponent(_RadioControl.RadioControl);
  });
  it('does not render a `RadioControl` component as the `Choice` when `value` is a single string', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList).not.toContainReactComponent(_Checkbox.CheckboxControl);
  });
  it('renders a `CheckboxControl` component as the `Choice` when `value` is a string array', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList).toContainReactComponent(_Checkbox.CheckboxControl);
  });
  it('does not render a `RadioControl` component as the `Choice` when `value` is a string array', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList).not.toContainReactComponent(_RadioControl.RadioControl);
  });
  it('passes its name down to its `RadioControl` component', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(_RadioControl.RadioControl)).toHaveReactProps({
      name: defaultProps.name
    });
  });
  it('passes its onChange down to its `RadioControl` component', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(_RadioControl.RadioControl)).toHaveReactProps({
      onChange: expect.any(Function)
    });
  });
  it('sets a checked prop on its `RadioControl` component whose id equals the Choice value', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: singleValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(_RadioControl.RadioControl)).toHaveReactProps({
      checked: true
    });
  });
  it('does not set a checked prop on its `RadioControl` component whose id does not equal the Choice value', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: "",
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(_RadioControl.RadioControl)).toHaveReactProps({
      checked: false
    });
  });
  it('passes its name down to its `CheckboxControl` component', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(_Checkbox.CheckboxControl)).toHaveReactProps({
      name: defaultProps.name
    });
  });
  it('passes its onChange down to its `CheckboxControl` component', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(_Checkbox.CheckboxControl)).toHaveReactProps({
      onChange: expect.any(Function)
    });
  });
  it('sets a checked prop on its `CheckboxControl` component whose id is contained in the Choice value', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: multiValue,
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(_Checkbox.CheckboxControl)).toHaveReactProps({
      checked: true
    });
  });
  it('does not set a checked prop on its `CheckboxControl` component whose id is not contained in the Choice value', () => {
    const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
      value: [''],
      onChange: noop
    }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
      id: id
    }, labelContent)));
    expect(choiceList.find(_Checkbox.CheckboxControl)).toHaveReactProps({
      checked: false
    });
  });
  describe('<Choice />', () => {
    it('renders children as its label content', () => {
      const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
        value: multiValue,
        onChange: noop
      }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
        id: id
      }, labelContent)));
      expect(choiceList.find('label')).toHaveReactProps({
        children: labelContent
      });
    });
    it('sets an aria-label on the Choice label when accessibilityLabel is provided', () => {
      const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
        value: multiValue,
        onChange: noop
      }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
        id: id,
        accessibilityLabel: accessibilityLabel
      }, labelContent)));
      expect(choiceList.find('label')).toHaveReactProps({
        'aria-label': accessibilityLabel
      });
    });
    it('does not set an aria-label on the Choice label when accessibilityLabel is not provided', () => {
      const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
        value: multiValue,
        onChange: noop
      }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
        id: id
      }, labelContent)));
      expect(choiceList.find('label')).not.toHaveReactProps({
        'aria-label': accessibilityLabel
      });
    });
    it('calls its `onChange` handler with a string value when checked on a choicelist with a string value', () => {
      const onChangeSpy = jest.fn();
      const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
        value: "",
        onChange: onChangeSpy
      }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
        id: id
      }, labelContent)));
      choiceList.find(_RadioControl.RadioControl).trigger('onChange', true);
      expect(onChangeSpy).toHaveBeenCalledWith(id);
    });
    it('calls its `onChange` handler with a string value when unchecked on a choicelist with a string value', () => {
      const onChangeSpy = jest.fn();
      const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
        value: singleValue,
        onChange: onChangeSpy
      }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
        id: id
      }, labelContent)));
      choiceList.find(_RadioControl.RadioControl).trigger('onChange', false);
      expect(onChangeSpy).toHaveBeenCalledWith('');
    });
    it('calls its `onChange` handler with a string array value when checked on a choicelist with a string array value', () => {
      const onChangeSpy = jest.fn();
      const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
        value: [],
        onChange: onChangeSpy
      }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
        id: id
      }, labelContent)));
      choiceList.find(_Checkbox.CheckboxControl).trigger('onChange', true);
      expect(onChangeSpy).toHaveBeenCalledWith([id]);
    });
    it('calls its `onChange` handler with a string array value when unchecked on a choicelist with a string array value', () => {
      const onChangeSpy = jest.fn();
      const choiceList = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ChoiceList.ChoiceList, Object.assign({}, defaultProps, {
        value: multiValue,
        onChange: onChangeSpy
      }), /*#__PURE__*/_react.default.createElement(_ChoiceList.Choice, {
        id: id
      }, labelContent)));
      choiceList.find(_Checkbox.CheckboxControl).trigger('onChange', false);
      expect(onChangeSpy).toHaveBeenCalledWith([]);
    });
  });
});

function noop() {}