"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Form = Form;

var _react = _interopRequireWildcard(require("react"));

var _View = require("../View");

var _id = require("../../utilities/id");

var _forms = require("../../utilities/forms");

var _Portal = require("../Portal");

var _AppContext = require("../AppContext");

var _Form = _interopRequireDefault(require("./Form.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createId = (0, _id.createIdCreator)('Form');

function Form({
  onSubmit,
  children,
  implicitSubmit = true,
  disabled = false,
  id
}) {
  const translate = (0, _AppContext.useTranslate)();
  const generatedId = (0, _id.useId)(undefined, createId);
  const formId = id !== null && id !== void 0 ? id : generatedId;
  const nested = (0, _forms.useContainingForm)() != null;
  const formDetails = (0, _react.useMemo)(() => ({
    id: formId,
    nested
  }), [formId, nested]);
  let implicitSubmitContent = null;

  if (implicitSubmit) {
    implicitSubmitContent = /*#__PURE__*/_react.default.createElement(_View.View, {
      visibility: "hidden"
    }, /*#__PURE__*/_react.default.createElement(ImplicitSubmitter, {
      disabled: disabled,
      form: formDetails
    }, typeof implicitSubmit === 'string' ? implicitSubmit : translate('submit')));
  }

  const handleSubmit = event => {
    event.preventDefault();
    event.stopPropagation();
    if (disabled) return;
    onSubmit();
  };

  return nested ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_forms.FormContext.Provider, {
    value: formDetails
  }, children, implicitSubmitContent), /*#__PURE__*/_react.default.createElement(_Portal.Portal, null, /*#__PURE__*/_react.default.createElement("form", {
    action: "",
    method: "POST",
    noValidate: true,
    className: _Form.default.Form,
    id: formId,
    onSubmit: handleSubmit
  }))) : /*#__PURE__*/_react.default.createElement("form", {
    action: "",
    method: "POST",
    noValidate: true,
    className: _Form.default.Form,
    id: formId,
    onSubmit: handleSubmit
  }, /*#__PURE__*/_react.default.createElement(_forms.FormContext.Provider, {
    value: formDetails
  }, children, implicitSubmitContent));
}

function ImplicitSubmitter({
  form,
  children,
  disabled
}) {
  return /*#__PURE__*/_react.default.createElement("button", {
    type: "submit",
    disabled: disabled,
    tabIndex: -1,
    "aria-hidden": true,
    form: form.nested ? form.id : undefined
  }, children);
}