"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Hidden = Hidden;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _inlineFormatting = require("../../utilities/inlineFormatting");

var _Hidden = _interopRequireDefault(require("./Hidden.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const VIEWPORT_SIZES = ['small', 'medium', 'large'];

/**
 * Hidden is used to hide content from users based on their viewport size.
 */
function Hidden({
  above,
  below,
  children
}) {
  const inline = (0, _inlineFormatting.useInlineFormatting)();
  const Component = inline ? 'span' : 'div';
  const {
    hiddenOnSmall,
    hiddenOnMedium,
    hiddenOnLarge
  } = getResponsiveValuesFromRange(above, below);
  const className = (0, _cssUtilities.classNames)(_Hidden.default.Hidden, hiddenOnSmall && _Hidden.default.hiddenOnSmall, hiddenOnMedium && _Hidden.default.hiddenOnMedium, hiddenOnLarge && _Hidden.default.hiddenOnLarge);
  return /*#__PURE__*/_react.default.createElement(Component, {
    className: className
  }, children);
}

function getResponsiveValuesFromRange(above, below) {
  if (above === below) {
    return {
      hiddenOnSmall: true,
      hiddenOnMedium: false,
      hiddenOnLarge: true
    };
  }

  const start = above ? VIEWPORT_SIZES.indexOf(above) + 1 : 0;
  const end = below ? VIEWPORT_SIZES.indexOf(below) - 1 : VIEWPORT_SIZES.length - 1;
  const range = VIEWPORT_SIZES.slice(start, end + 1);
  const hiddenOnSmall = range.indexOf('small') >= 0;
  const hiddenOnMedium = range.indexOf('medium') >= 0;
  const hiddenOnLarge = range.indexOf('large') >= 0;
  return {
    hiddenOnSmall,
    hiddenOnMedium,
    hiddenOnLarge
  };
}