"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _TextBlock = require("../TextBlock");

var _Hidden = require("./Hidden");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Hidden />', () => {
  it('renders its children', () => {
    const text = 'Snowdevil';
    const hidden = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Hidden.Hidden, {
      below: "medium"
    }, text));
    expect(hidden).toContainReactText(text);
  });
  it('renders a <div> by default', () => {
    const text = 'Snowdevil';
    const hidden = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Hidden.Hidden, {
      below: "medium"
    }, text));
    expect(hidden).toContainReactComponent('div');
  });
  it('renders a <span> when used inside an inline formatting context', () => {
    const text = 'Snowdevil';
    const hiddenTextBlock = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_TextBlock.TextBlock, null, /*#__PURE__*/_react.default.createElement(_Hidden.Hidden, {
      below: "medium"
    }, text)));
    expect(hiddenTextBlock).toContainReactComponent('span');
  });
  describe('above', () => {
    it('applies CSS classes that hides the element above the specified breakpoint', () => {
      const text = 'Snowdevil';
      const hiddenAboveSmall = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Hidden.Hidden, {
        above: "small"
      }, text));
      const hiddenAboveMedium = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Hidden.Hidden, {
        above: "medium"
      }, text));
      expect(hiddenAboveSmall).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnMedium hiddenOnLarge')
      });
      expect(hiddenAboveMedium).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnLarge')
      });
    });
  });
  describe('below', () => {
    it('applies CSS classes that hides the element below the specified breakpoint', () => {
      const text = 'Snowdevil';
      const hiddenBelowMedium = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Hidden.Hidden, {
        below: "medium"
      }, text));
      const hiddenBelowLarge = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Hidden.Hidden, {
        below: "large"
      }, text));
      expect(hiddenBelowMedium).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnSmall')
      });
      expect(hiddenBelowLarge).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnSmall hiddenOnMedium')
      });
    });
  });
  describe('below and above combined', () => {
    it('applies CSS classes that hides the element when both below and above is specified', () => {
      const text = 'Snowdevil';
      const hiddenBelowLargeAboveSmall = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Hidden.Hidden, {
        above: "small",
        below: "large"
      }, text));
      const hiddenBelowMediumAboveMedium = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Hidden.Hidden, {
        above: "medium",
        below: "medium"
      }, text));
      expect(hiddenBelowLargeAboveSmall).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnMedium')
      });
      expect(hiddenBelowMediumAboveMedium).toContainReactComponent('div', {
        className: expect.stringContaining('hiddenOnSmall hiddenOnLarge')
      });
    });
  });
});