"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _faker = _interopRequireDefault(require("faker"));

var _View = require("../View");

var _Image = require("./Image");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Image />', () => {
  const source = _faker.default.image.imageUrl();

  describe('sources', () => {
    it('renders a picture element with sources with an img fallback', () => {
      const description = _faker.default.random.words();

      const image = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Image.Image, {
        source: source,
        sources: [{
          source
        }],
        description: description,
        loading: "lazy"
      }));
      expect(image).toContainReactComponent('picture');
      expect(image).toContainReactComponent('source', {
        srcSet: source
      });
      expect(image).toContainReactComponent('img', {
        src: source,
        alt: description,
        loading: 'lazy'
      });
    });
    it('reduces multiple sources with the same viewportSize into a single srcSet', () => {
      const image = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Image.Image, {
        source: source,
        sources: [{
          source,
          viewportSize: 'small',
          resolution: 1
        }, {
          source,
          viewportSize: 'small',
          resolution: 2
        }],
        loading: "lazy"
      }));
      expect(image).toContainReactComponent('source', {
        srcSet: `${source} 1x, ${source} 2x`,
        media: _Image.MEDIA_MAP.get('small')
      });
    });
    it('renders an img element only when no sources are provided', () => {
      const image = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Image.Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent('picture');
      expect(image).not.toContainReactComponent('source');
      expect(image).toContainReactComponent('img', {
        src: source
      });
    });
  });
  describe('decorative', () => {
    it('wraps the image with <View accessibilityVisibility="hidden" />', () => {
      const image = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Image.Image, {
        source: source,
        decorative: true
      }));
      expect(image).toContainReactComponent(_View.View, {
        accessibilityVisibility: 'hidden'
      });
    });
    it('by default the image is not wrapped with <View accessibilityVisibility="hidden" />', () => {
      const image = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Image.Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent(_View.View, {
        accessibilityVisibility: 'hidden'
      });
    });
  });
  describe('aspectRatio', () => {
    it('wraps the image with placeholder container', () => {
      const image = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Image.Image, {
        source: source,
        aspectRatio: 16 / 9
      }));
      expect(image).toContainReactComponent('div', {
        style: {
          paddingBottom: `calc(100% / ${16 / 9})`
        }
      });
    });
    it('by default the image does not have any container', () => {
      const image = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Image.Image, {
        source: source
      }));
      expect(image).not.toContainReactComponent('div');
    });
  });
});