"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _View = require("../View");

var _context = require("./context");

var _OptionList = require("./OptionList");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  id: _faker.default.random.uuid(),
  selectedItems: [_faker.default.random.uuid()],
  onChange: () => null,
  children: /*#__PURE__*/_react.default.createElement("div", null)
};
describe('<OptionList />', () => {
  it('renders its children', () => {
    function Children() {
      return /*#__PURE__*/_react.default.createElement("div", null, "children");
    }

    const accordion = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, defaultProps, /*#__PURE__*/_react.default.createElement(Children, null)));
    expect(accordion).toContainReactComponent(Children);
  });
  it('wraps children with OptionListContext', () => {
    const id = _faker.default.random.uuid();

    const selectedItems = [_faker.default.random.uuid()];

    const onChange = () => null;

    const allowMultiple = false;
    const controlHidden = false;
    const accordion = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, Object.assign({}, defaultProps, {
      id: id,
      selectedItems: selectedItems,
      onChange: onChange,
      allowMultiple: allowMultiple
    })));
    expect(accordion).toProvideReactContext(_context.OptionListContext, {
      id,
      selectedItems,
      onChange,
      allowMultiple,
      controlHidden
    });
  });
  it('renders a title if provided', () => {
    const title = _faker.default.random.word();

    const accordion = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, Object.assign({}, defaultProps, {
      title: title
    })));
    expect(accordion).toContainReactComponent('legend');
    expect(accordion.find('legend')).toContainReactText(title);
  });
  it('renders a hidden title if provided when titleHidden prop is set to true', () => {
    const title = _faker.default.random.word();

    const accordion = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_OptionList.OptionList, Object.assign({}, defaultProps, {
      title: title,
      titleHidden: true
    })));
    expect(accordion.find(_View.View, {
      visibility: 'hidden'
    })).toContainReactComponent('legend');
    expect(accordion.find('legend')).toContainReactText(title);
  });
});