"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Option = Option;
exports.OptionPrimaryContent = OptionPrimaryContent;
exports.OptionSecondaryContent = OptionSecondaryContent;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Bookend = require("../../../Bookend");

var _Text = require("../../../Text");

var _Heading = require("../../../Heading");

var _RadioControl = require("../../../RadioControl");

var _Checkbox = require("../../../Checkbox");

var _View = require("../../../View");

var _Theme = require("../../../Theme");

var _hooks = require("../../hooks");

var _OptionList = _interopRequireDefault(require("../../OptionList.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Option({
  id,
  label,
  details,
  children
}) {
  const {
    id: optionListId,
    selectedItems,
    allowMultiple,
    controlHidden,
    onChange
  } = (0, _hooks.useOptionList)();
  const Control = allowMultiple ? _Checkbox.CheckboxControl : _RadioControl.RadioControl;
  const checked = selectedItems.includes(id);
  const {
    optionList: {
      spacing = 'none',
      typographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  const className = (0, _cssUtilities.classNames)(_OptionList.default.Option, spacing !== 'none' && _OptionList.default.isContainer);

  function getNewSelections() {
    if (!allowMultiple) {
      return [id];
    }

    if (checked) {
      return selectedItems.filter(selectedItem => selectedItem !== id);
    }

    return [...selectedItems, id];
  }

  const hideChildrenForAccessibility = Boolean(label && children);
  return controlHidden ? /*#__PURE__*/_react.default.createElement("div", {
    className: className
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _OptionList.default.OptionLabel
  }, hideChildrenForAccessibility ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_View.View, {
    visibility: "hidden"
  }, label), /*#__PURE__*/_react.default.createElement("div", {
    "aria-hidden": "true"
  }, /*#__PURE__*/_react.default.createElement(_Bookend.Bookend, {
    trailing: true
  }, children))) : /*#__PURE__*/_react.default.createElement(_Heading.Heading, null, /*#__PURE__*/_react.default.createElement(_Text.Text, {
    emphasized: typographyStyle == null,
    style: typographyStyle
  }, label))), details) : /*#__PURE__*/_react.default.createElement("div", {
    className: className
  }, /*#__PURE__*/_react.default.createElement("label", {
    htmlFor: `${optionListId}-${id}`,
    className: (0, _cssUtilities.classNames)(_OptionList.default.OptionLabel, _OptionList.default['OptionLabel-cursorPointer'])
  }, /*#__PURE__*/_react.default.createElement(_Bookend.Bookend, {
    leading: true
  }, /*#__PURE__*/_react.default.createElement(Control, {
    id: `${optionListId}-${id}`,
    name: `${optionListId}`,
    checked: checked,
    onChange: () => {
      onChange(getNewSelections());
    }
  }), hideChildrenForAccessibility ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_View.View, {
    visibility: "hidden"
  }, label), /*#__PURE__*/_react.default.createElement("div", {
    "aria-hidden": "true"
  }, /*#__PURE__*/_react.default.createElement(_Bookend.Bookend, {
    trailing: true
  }, children))) : /*#__PURE__*/_react.default.createElement(_Text.Text, {
    emphasized: typographyStyle == null,
    style: typographyStyle
  }, label))), details);
}

function OptionPrimaryContent({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _OptionList.default.PrimaryContent
  }, children);
}

function OptionSecondaryContent({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _OptionList.default.SecondaryContent
  }, children);
}