"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _Popper = require("./Popper");

var _context = require("./context");

var _offsets = require("./utilities/offsets");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  activator: null
};
describe('<Popper />', () => {
  it('render its children', () => {
    const content = 'content';
    const popper = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Popper.Popper, defaultProps, content));
    expect(popper).toContainReactText('content');
  });
  it('wraps children with PopperContext', () => {
    const content = 'content';
    const placement = 'blockEnd';
    const popper = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Popper.Popper, Object.assign({
      placement: placement
    }, defaultProps), content));
    expect(popper).toProvideReactContext(_context.PopperContext, {
      offsets: {
        x: 0,
        y: 0
      },
      clipping: {
        left: 0,
        right: 0
      },
      spacing: 0,
      placement,
      popperRect: {
        bottom: 0,
        height: 0,
        left: 0,
        right: 0,
        top: 0,
        width: 0
      },
      referenceRect: null
    });
  });
  describe('computeOffsets', () => {
    it('computes default offsets when reference and popper rect are null', () => {
      const {
        offsets
      } = (0, _offsets.computeOffsets)('blockStart', null, null);
      expect(offsets).toStrictEqual({
        x: 0,
        y: 0
      });
    });
    it('computes top center offsets with reference larger than popper', () => {
      const referenceWidth = 100;
      const referenceHeight = 40;
      const popperWidth = 40;
      const popperHeight = 20;
      const referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      const popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };
      const {
        offsets
      } = (0, _offsets.computeOffsets)('blockStart', popperRect, referenceRect);
      expect(offsets).toStrictEqual({
        x: 130,
        y: 80
      });
      expect(offsets.x).toBeGreaterThan(referenceRect.left);
      expect(offsets.y).toBeLessThan(referenceRect.top);
    });
    it('computes bottom center offsets with reference larger than popper', () => {
      const referenceWidth = 100;
      const referenceHeight = 40;
      const popperWidth = 40;
      const popperHeight = 20;
      const referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      const popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };
      const {
        offsets
      } = (0, _offsets.computeOffsets)('blockEnd', popperRect, referenceRect);
      expect(offsets).toStrictEqual({
        x: 130,
        y: 140
      });
      expect(offsets.x).toBeGreaterThan(referenceRect.left);
      expect(offsets.y).toBeGreaterThan(referenceRect.top);
    });
    it('computes top center offsets with reference smaller than popper', () => {
      const referenceWidth = 40;
      const referenceHeight = 20;
      const popperWidth = 100;
      const popperHeight = 40;
      const referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      const popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };
      const {
        offsets
      } = (0, _offsets.computeOffsets)('blockStart', popperRect, referenceRect);
      expect(offsets).toStrictEqual({
        x: 70,
        y: 60
      });
      expect(offsets.x).toBeLessThan(referenceRect.left);
      expect(offsets.y).toBeLessThan(referenceRect.top);
    });
    it('computes bottom center offsets with reference smaller than popper', () => {
      const referenceWidth = 40;
      const referenceHeight = 20;
      const popperWidth = 100;
      const popperHeight = 40;
      const referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      const popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };
      const {
        offsets
      } = (0, _offsets.computeOffsets)('blockEnd', popperRect, referenceRect);
      expect(offsets).toStrictEqual({
        x: 70,
        y: 120
      });
      expect(offsets.x).toBeLessThan(referenceRect.left);
      expect(offsets.y).toBeGreaterThan(referenceRect.top);
    });
    it('computes offsets with reference larger than popper and sameInlineSize option', () => {
      const referenceWidth = 100;
      const referenceHeight = 40;
      const popperWidth = 40;
      const popperHeight = 20;
      const referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      const popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };
      const {
        offsets
      } = (0, _offsets.computeOffsets)('blockStart', popperRect, referenceRect, {
        sameInlineSize: true
      });
      expect(offsets).toStrictEqual({
        x: 100,
        y: 80
      });
      expect(offsets.x).toBe(referenceRect.left);
      expect(offsets.y).toBeLessThan(referenceRect.top);
    });
  });
});