"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _TextBlock = require("../../../TextBlock");

var _ProgressTracker = require("../../ProgressTracker");

var _View = require("../../../View");

var _ProgressTrackerStep = require("./ProgressTrackerStep");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = id => ({
  id: `step${id}`,
  icon: 'checkmark',
  label: `Step ${id}`,
  state: `State ${id}`
});

describe('<ProgressTrackerStep />', () => {
  it('renders a <ProgressTrackerStepConnector /> except for first ProgressTrackerStep', () => {
    const progressTracker = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_ProgressTracker.ProgressTracker, {
      activeStep: "step3"
    }, /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(1)), /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(2)), /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(3))));
    const [firstProgressTrackerStep, secondProgressTrackerStep, finalProgressTrackerStep] = progressTracker.findAll(_ProgressTrackerStep.ProgressTrackerStep);
    expect(firstProgressTrackerStep).not.toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepConnector);
    expect(secondProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepConnector, {
      active: false,
      completed: true
    });
    expect(finalProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepConnector, {
      active: true,
      completed: false
    });
  });
  it('renders <ProgressTrackerStepIcon />', () => {
    const progressTracker = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_ProgressTracker.ProgressTracker, {
      activeStep: "step2"
    }, /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(1)), /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(2)), /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, Object.assign({}, defaultProps(3), {
      iconAppearance: "critical"
    }))));
    const [firstProgressTrackerStep, secondProgressTrackerStep, finalProgressTrackerStep] = progressTracker.findAll(_ProgressTrackerStep.ProgressTrackerStep);
    expect(firstProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepIcon, {
      active: false,
      completed: true,
      source: 'checkmark'
    });
    expect(secondProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepIcon, {
      active: true,
      completed: false,
      source: 'checkmark'
    });
    expect(finalProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepIcon, {
      active: false,
      completed: false,
      source: 'checkmark',
      appearance: 'critical'
    });
  });
  it('renders <ProgressTrackerStepLabel /> with state', () => {
    const progressTracker = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_ProgressTracker.ProgressTracker, null, /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(1)), /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, Object.assign({}, defaultProps(2), {
      stateHidden: false
    }))));
    const [firstProgressTrackerStep, finalProgressTrackerStep] = progressTracker.findAll(_ProgressTrackerStep.ProgressTrackerStep);
    expect(firstProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepLabel, {
      state: 'State 1'
    });
    expect(finalProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepLabel, {
      state: 'State 2'
    });
    expect(firstProgressTrackerStep).toContainReactComponent(_View.View, {
      visibility: 'hidden'
    });
    expect(firstProgressTrackerStep).toContainReactComponentTimes(_TextBlock.TextBlock, 1);
    expect(finalProgressTrackerStep).not.toContainReactComponent(_View.View, {
      visibility: 'hidden'
    });
    expect(finalProgressTrackerStep).toContainReactComponentTimes(_TextBlock.TextBlock, 2);
    expect(firstProgressTrackerStep.find(_View.View, {
      visibility: 'hidden'
    })).toContainReactText('State 1');
    expect(finalProgressTrackerStep.find(_TextBlock.TextBlock)).toContainReactText('State 2');
  });
  it('renders <ProgressTrackerStepLabel /> with label or description', () => {
    const progressTracker = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_ProgressTracker.ProgressTracker, {
      activeStep: "step2"
    }, /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, Object.assign({}, defaultProps(1), {
      description: "Description 1"
    })), /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, Object.assign({}, defaultProps(2), {
      description: "Description 2"
    })), /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(3))));
    const [firstProgressTrackerStep, secondProgressTrackerStep, finalProgressTrackerStep] = progressTracker.findAll(_ProgressTrackerStep.ProgressTrackerStep);
    expect(firstProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepLabel, {
      label: 'Step 1',
      description: 'Description 1'
    });
    expect(secondProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepLabel, {
      label: 'Step 2',
      description: 'Description 2'
    });
    expect(finalProgressTrackerStep).toContainReactComponent(_ProgressTrackerStep.ProgressTrackerStepLabel, {
      label: 'Step 3'
    });
    expect(firstProgressTrackerStep.find(_TextBlock.TextBlock)).toContainReactText('Step 1');
    expect(secondProgressTrackerStep.find(_TextBlock.TextBlock)).toContainReactText('Step 2');
    expect(finalProgressTrackerStep.find(_TextBlock.TextBlock)).toContainReactText('Step 3');
    expect(firstProgressTrackerStep).toContainReactComponentTimes(_TextBlock.TextBlock, 2);
    expect(secondProgressTrackerStep).toContainReactComponentTimes(_TextBlock.TextBlock, 2);
    expect(finalProgressTrackerStep).toContainReactComponentTimes(_TextBlock.TextBlock, 1);
  });
  it('renders a <li> with a aria-current attribute', () => {
    const progressTracker = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_ProgressTracker.ProgressTracker, {
      activeStep: "step2"
    }, /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(1)), /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(2)), /*#__PURE__*/_react.default.createElement(_ProgressTrackerStep.ProgressTrackerStep, defaultProps(3))));
    const [firstProgressTrackerStep, secondProgressTrackerStep, finalProgressTrackerStep] = progressTracker.findAll(_ProgressTrackerStep.ProgressTrackerStep);
    expect(firstProgressTrackerStep).toContainReactComponent('li', {
      'aria-current': false
    });
    expect(secondProgressTrackerStep).toContainReactComponent('li', {
      'aria-current': true
    });
    expect(finalProgressTrackerStep).toContainReactComponent('li', {
      'aria-current': false
    });
  });
});