"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _Link = require("../Link");

var _Heading = require("../Heading");

var _ReviewItem = require("./ReviewItem");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  label: 'Contact',
  children: 'snowdevil@shopify.com'
};
describe('<ReviewItem />', () => {
  describe('label', () => {
    it('renders the label', () => {
      const label = 'Ship to';
      const reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ReviewItem.ReviewItem, Object.assign({}, defaultProps, {
        label: label
      })));
      expect(reviewItem).toContainReactText(label);
    });
  });
  describe('children', () => {
    it('does not render a link when not provided', () => {
      const content = 'snowdevil@shopify.com';
      const reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ReviewItem.ReviewItem, defaultProps, content));
      expect(reviewItem).toContainReactText(content);
    });
  });
  it('does not render a link when `to` is not provided', () => {
    const reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ReviewItem.ReviewItem, {
      label: "Content"
    }, "snowdevil@shopify.com"));
    expect(reviewItem).not.toContainReactComponent(_Link.Link);
  });
  it('renders a link when `to` is provided', () => {
    const to = '/payment';
    const reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ReviewItem.ReviewItem, Object.assign({}, defaultProps, {
      to: to
    })));
    expect(reviewItem).toContainReactComponent(_Link.Link, {
      to
    });
  });
  it('sets an aria-label on Link when `linkAccessibilityLabel` is provided', () => {
    const reviewItem = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ReviewItem.ReviewItem, Object.assign({}, defaultProps, {
      to: "/information",
      linkLabel: "Change",
      linkAccessibilityLabel: "Change contact information"
    })));
    expect(reviewItem).toContainReactComponent(_Link.Link, {
      accessibilityLabel: 'Change contact information'
    });
  });
});
describe('<ReviewBlock />', () => {
  it('renders the children', () => {
    const reviewBlock = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ReviewItem.ReviewBlock, null, /*#__PURE__*/_react.default.createElement(_ReviewItem.ReviewItem, Object.assign({}, defaultProps, {
      label: "Ship to"
    }))));
    expect(reviewBlock).toContainReactComponent(_ReviewItem.ReviewItem);
  });
  it('renders a <Heading /> when a title is passed as a prop', () => {
    const reviewBlock = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ReviewItem.ReviewBlock, {
      title: "Review"
    }));
    const heading = reviewBlock.find(_Heading.Heading);
    expect(heading).toContainReactText('Review');
    expect(reviewBlock).toContainReactComponent('div', {
      'aria-labelledby': heading === null || heading === void 0 ? void 0 : heading.prop('id')
    });
  });
  it('links the Heading with the section using aria-labelledBy', () => {
    const reviewBlock = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_ReviewItem.ReviewBlock, {
      title: "Review",
      titleHidden: true
    }));
    const heading = reviewBlock.find(_Heading.Heading);
    expect(reviewBlock).toContainReactComponent('div', {
      'aria-labelledby': heading === null || heading === void 0 ? void 0 : heading.prop('id')
    });
  });
});