"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Step = Step;
exports.StepContent = StepContent;
exports.StepSection = StepSection;
exports.StepSectionHeader = StepSectionHeader;
exports.StepSectionContent = StepSectionContent;
exports.StepSectionShowcase = StepSectionShowcase;
exports.StepActions = StepActions;
exports.StepPrimaryAction = StepPrimaryAction;
exports.StepSecondaryAction = StepSecondaryAction;
exports.STEP_SECTION_PRIMARY_HEADER_ID = void 0;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Heading = require("../Heading");

var _HeadingGroup = require("../HeadingGroup");

var _TextBlock = require("../TextBlock");

var _TextContainer = require("../TextContainer");

var _Theme = require("../Theme");

var _Step = _interopRequireDefault(require("./Step.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Step({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Step.default.Step
  }, children);
}

function StepContent({
  grouped,
  children
}) {
  const className = (0, _cssUtilities.classNames)(_Step.default.Content, {
    [_Step.default.isGrouped]: grouped
  });
  return /*#__PURE__*/_react.default.createElement("div", {
    className: className
  }, children);
}

function StepSection({
  children,
  title
}) {
  return /*#__PURE__*/_react.default.createElement("section", {
    "aria-label": title,
    className: _Step.default.Section
  }, children);
}

const STEP_SECTION_PRIMARY_HEADER_ID = 'primary-header';
exports.STEP_SECTION_PRIMARY_HEADER_ID = STEP_SECTION_PRIMARY_HEADER_ID;

function StepSectionHeader({
  title,
  primary,
  description
}) {
  return /*#__PURE__*/_react.default.createElement(_TextContainer.TextContainer, {
    spacing: "tight"
  }, title ? /*#__PURE__*/_react.default.createElement(_Heading.Heading, {
    id: primary ? STEP_SECTION_PRIMARY_HEADER_ID : undefined
  }, title) : null, description ? /*#__PURE__*/_react.default.createElement(_TextBlock.TextBlock, null, description) : null);
}

function StepSectionContent({
  children
}) {
  return /*#__PURE__*/_react.default.createElement(_HeadingGroup.HeadingGroup, null, children);
}

function StepSectionShowcase({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Step.default.Showcase
  }, children);
}

function StepActions({
  children
}) {
  const {
    actions: {
      display = 'inline'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const className = (0, _cssUtilities.classNames)(_Step.default.Actions, _Step.default[(0, _cssUtilities.variationName)('Actions-display', display)]);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: className
  }, children);
}

function StepPrimaryAction({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Step.default.PrimaryAction
  }, children);
}

function StepSecondaryAction({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Step.default.SecondaryAction
  }, children);
}