"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Stepper = Stepper;

var _react = _interopRequireWildcard(require("react"));

var _BlockStack = require("../BlockStack");

var _TextField = require("../TextField");

var _Connected = require("../Connected");

var _Button = require("../Button");

var _InlineError = require("../InlineError");

var _id = require("../../utilities/id");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createId = (0, _id.createIdCreator)('StepperField');

function Stepper({
  label,
  error,
  name,
  min = 0,
  max,
  value,
  step = 1,
  id: explicitId,
  required,
  onChange,
  onBlur,
  onFocus
}) {
  const [quantity, setQuantity] = (0, _react.useState)(value);
  const id = (0, _id.useId)(explicitId, createId);

  const errorMarkup = error && /*#__PURE__*/_react.default.createElement(_InlineError.InlineError, {
    controlID: id
  }, error);

  const handleChange = (0, _react.useCallback)(factor => {
    setQuantity(prevQuantity => {
      const normalizedMax = max === undefined ? Infinity : max;
      const normalizedMin = min === undefined ? -Infinity : min;
      const quantity = prevQuantity ? prevQuantity : 0;

      if (isNaN(quantity)) {
        return 0;
      } // Returns the length of decimal places in a number


      const decimalLength = num => (num.toString().split('.')[1] || []).length; // Making sure the new value has the same length of decimal places as the
      // step / value has.


      const decimalPlaces = Math.max(decimalLength(quantity), decimalLength(step));
      const newQuantity = Math.min(Number(normalizedMax), Math.max(quantity + factor * step, Number(normalizedMin)));

      if (quantity !== newQuantity) {
        onChange === null || onChange === void 0 ? void 0 : onChange(newQuantity.toFixed(decimalPlaces));
      }

      return parseFloat(newQuantity.toFixed(decimalPlaces));
    });
  }, [onChange, step, max, min]);
  return /*#__PURE__*/_react.default.createElement(_BlockStack.BlockStack, {
    spacing: "tight"
  }, /*#__PURE__*/_react.default.createElement(_Connected.Connected, {
    trailing: "auto",
    leading: "auto"
  }, /*#__PURE__*/_react.default.createElement(_Button.Button, {
    onPress: () => handleChange(-1)
  }, "-"), /*#__PURE__*/_react.default.createElement(_TextField.TextFieldInternal, {
    label: label,
    type: "number",
    min: min,
    max: max,
    step: step,
    id: id,
    error: Boolean(error),
    name: name,
    "aria-required": required,
    value: quantity === undefined ? '' : `${quantity}`,
    required: required,
    onChange: value => {
      setQuantity(Number(value));

      if (onChange) {
        onChange(value);
      }
    },
    onBlur: onBlur,
    onFocus: onFocus
  }), /*#__PURE__*/_react.default.createElement(_Button.Button, {
    onPress: () => handleChange(1)
  }, "+")), errorMarkup);
}