"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Field = exports.TextFieldInternal = exports.TextField = void 0;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _View = require("../View");

var _Labelled = require("../Labelled");

var _Icon = require("../Icon");

var _InlineError = require("../InlineError");

var _BlockStack = require("../BlockStack");

var _Theme = require("../Theme");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _strings = require("../../utilities/strings");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _autocomplete = require("../../utilities/autocomplete");

var _forms = require("../../utilities/forms");

var _TextField = _interopRequireDefault(require("./TextField.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createId = (0, _id.createIdCreator)('TextField');

/**
 * A text field is an input field that merchants can type into.
 */
const TextField = /*#__PURE__*/(0, _react.forwardRef)((props, ref) => /*#__PURE__*/_react.default.createElement(TextFieldInternal, Object.assign({}, props, {
  ref: ref
})));
exports.TextField = TextField;
const TextFieldInternal = /*#__PURE__*/(0, _react.forwardRef)((props, ref) => {
  const {
    controls: {
      background: controlsBackground
    },
    textFields: {
      labelPosition,
      background: textFieldsBackground,
      errorIndentation,
      errorTypographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  const background = textFieldsBackground || controlsBackground || 'surfaceTertiary';
  const {
    accessibilityDescription,
    error,
    id: explicitId,
    label,
    value: explicitValue,
    controlledValue,
    onInput,
    children,
    multiline,
    onChange
  } = props;
  const wrapperRef = (0, _react.useRef)(null);
  const [focus, setFocus] = (0, _react.useState)(false);
  (0, _react.useLayoutEffect)(() => {
    if (!(wrapperRef === null || wrapperRef === void 0 ? void 0 : wrapperRef.current)) return;

    const handleFocus = () => {
      setFocus(true);
    };

    const handleBlur = () => {
      setFocus(false);
    };

    const fields = wrapperRef.current.querySelectorAll('input, textarea, select');

    for (const field of fields) {
      field.addEventListener('focus', handleFocus);
      field.addEventListener('blur', handleBlur);
    }

    return () => {
      for (const field of fields) {
        field.removeEventListener('focus', handleFocus);
        field.removeEventListener('blur', handleBlur);
      }
    };
  }, [children]);
  const id = (0, _id.useId)(explicitId, createId);
  const descriptionId = accessibilityDescription ? `${id}-description` : undefined;
  const description = descriptionId ? /*#__PURE__*/_react.default.createElement(_View.View, {
    visibility: "hidden",
    id: descriptionId
  }, accessibilityDescription) : null;
  const [localValue, setLocalValue] = usePartiallyControlledState(controlledValue !== null && controlledValue !== void 0 ? controlledValue : explicitValue);
  const handleInput = (0, _react.useCallback)(value => {
    onInput === null || onInput === void 0 ? void 0 : onInput(value);
    setLocalValue(value);
  }, [onInput, setLocalValue]);

  const errorMarkup = error && error !== true && /*#__PURE__*/_react.default.createElement("span", {
    className: (0, _cssUtilities.classNames)(errorIndentation && _TextField.default[(0, _cssUtilities.variationName)('Error-errorIndentation', errorIndentation)], errorTypographyStyle && _typographyStyles.default[errorTypographyStyle])
  }, /*#__PURE__*/_react.default.createElement(_InlineError.InlineError, {
    controlID: id
  }, error));

  function handleKeyDown(event) {
    if (multiline === false || !onChange) {
      return;
    }

    switch (event.key) {
      case 'Enter':
        onChange(event.currentTarget.value);
    }
  }

  return /*#__PURE__*/_react.default.createElement(_BlockStack.BlockStack, {
    spacing: "tight"
  }, /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, {
    label: label,
    htmlFor: id,
    empty: (0, _strings.isEmptyString)(localValue),
    position: labelPosition,
    background: background,
    subdued: props.readonly,
    prefixed: Boolean(props.prefix),
    hasIcon: Boolean(props.icon)
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_TextField.default.Wrapper, props.disabled && _TextField.default['Wrapper-disabled'], props.readonly && _TextField.default['Wrapper-readonly'], _TextField.default[(0, _cssUtilities.variationName)('Wrapper-background', background)]),
    ref: wrapperRef
  }, description, /*#__PURE__*/_react.default.createElement(Field, Object.assign({
    ref: ref
  }, props, {
    id: id,
    focus: focus,
    ariaDescribedBy: descriptionId,
    localValue: localValue,
    onInput: handleInput,
    onKeyDown: handleKeyDown
  })))), errorMarkup);
});
exports.TextFieldInternal = TextFieldInternal;
const Field = /*#__PURE__*/(0, _react.forwardRef)(function Field({
  id,
  min,
  max,
  step,
  maxLength,
  name,
  label,
  prefix,
  icon,
  suffix,
  value: explicitValue,
  localValue,
  type = 'text',
  role,
  required,
  error,
  focus,
  autocomplete,
  autofocus,
  multiline,
  disabled,
  readonly,
  children,
  ariaActiveDescendant,
  ariaAutocomplete,
  ariaControls,
  ariaDescribedBy,
  ariaExpanded,
  onFocus,
  onBlur,
  onChange,
  onInput,
  onKeyDown
}, ref) {
  const innerRef = (0, _react.useRef)();
  const refsSetter = (0, _react.useCallback)(instance => {
    if (typeof ref === 'function') {
      ref(instance);
    } else if (ref) {
      ref.current = instance;
    }

    innerRef.current = instance;
  }, [ref]);
  const form = (0, _forms.useContainingForm)();
  (0, _react.useEffect)(() => {
    if (autofocus) {
      var _innerRef$current;

      (_innerRef$current = innerRef.current) === null || _innerRef$current === void 0 ? void 0 : _innerRef$current.focus();
    }
  }, [autofocus]);
  const {
    controls: {
      background: controlsBackground
    },
    textFields: {
      labelPosition = 'inside',
      background: textFieldsBackground,
      border = 'full',
      borderColor = 'base',
      focusBorder = 'full',
      typographyStyle: style
    },
    label: {
      typographyStyle: placeholderStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  const background = textFieldsBackground || controlsBackground || 'surfaceTertiary';
  const labelled = (0, _Labelled.useLabelled)();
  const fieldWrapperClassName = (0, _cssUtilities.classNames)(_TextField.default['Field-Wrapper'], Boolean(multiline) && _TextField.default.multiline);

  const iconMarkup = icon && /*#__PURE__*/_react.default.createElement("div", {
    className: _TextField.default.Icon,
    "aria-hidden": "true",
    onClick: () => {
      var _innerRef$current2;

      return (_innerRef$current2 = innerRef.current) === null || _innerRef$current2 === void 0 ? void 0 : _innerRef$current2.focus();
    }
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _TextField.default.IconInner
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    appearance: "subdued",
    source: icon
  })));

  const prefixMarkup = prefix && (labelled.floating || labelPosition === 'outside') && /*#__PURE__*/_react.default.createElement("div", {
    id: `${id}-prefix`,
    className: (0, _cssUtilities.classNames)(_TextField.default.Prefix, labelPosition === 'inside' && _TextField.default['Prefix-inside']),
    "aria-hidden": "true",
    onClick: () => {
      var _innerRef$current3;

      return (_innerRef$current3 = innerRef.current) === null || _innerRef$current3 === void 0 ? void 0 : _innerRef$current3.focus();
    }
  }, prefix);

  const className = (0, _cssUtilities.classNames)(_TextField.default.Field, labelled.floating && labelPosition !== 'outside' && _TextField.default['Field-floating'], Boolean(prefix) && _TextField.default['Field-prefixed'], Boolean(children) && _TextField.default['Field-hasActions'], Boolean(multiline) && _TextField.default['Field-multiline'], style && _typographyStyles.default[style], placeholderStyle && _typographyStyles.default[(0, _cssUtilities.variationName)('placeholder', placeholderStyle)]);
  const backdropClassName = (0, _cssUtilities.classNames)(_TextField.default.Backdrop, focus && _TextField.default.focus, Boolean(error) && _TextField.default.hasError, _TextField.default[(0, _cssUtilities.variationName)('Backdrop-background', background)], _TextField.default[(0, _cssUtilities.variationName)('Backdrop-border', border)], _TextField.default[(0, _cssUtilities.variationName)('Backdrop-borderColor', borderColor)], _TextField.default[(0, _cssUtilities.variationName)('Backdrop-focusBorder', focusBorder)], disabled && _TextField.default['Backdrop-disabled'], readonly && _TextField.default['Backdrop-readOnly']);
  const finalDescribedBy = [ariaDescribedBy, error && (0, _errors.errorId)(id)].filter(Boolean).join(' ');

  const field = /*#__PURE__*/_react.default.createElement(multiline ? 'textarea' : 'input', {
    id,
    min,
    max,
    step,
    maxLength,
    name,
    placeholder: labelled.floating || labelPosition === 'outside' ? undefined : label,
    className,
    required,
    type: normalizeType(multiline ? undefined : type),
    disabled,
    readOnly: readonly,
    'aria-activedescendant': ariaActiveDescendant,
    'aria-autocomplete': ariaAutocomplete,
    'aria-controls': ariaControls,
    'aria-describedby': finalDescribedBy,
    'aria-expanded': ariaExpanded,
    'aria-invalid': Boolean(error),
    'aria-required': required,
    'aria-labelledby': `${id}-label${prefix ? ` ${id}-prefix` : ''}${suffix ? ` ${id}-suffix` : ''}`,
    onBlur: ({
      currentTarget: {
        value
      }
    }) => {
      const currentValue = explicitValue;
      if (value !== currentValue) onChange === null || onChange === void 0 ? void 0 : onChange(value);
      onBlur === null || onBlur === void 0 ? void 0 : onBlur();
      labelled.onBlur();
    },

    onChange({
      currentTarget: {
        value
      }
    }) {
      onInput === null || onInput === void 0 ? void 0 : onInput(value);
    },

    onFocus: () => {
      onFocus === null || onFocus === void 0 ? void 0 : onFocus();
      labelled.onFocus();
    },
    onKeyDown,
    ref: refsSetter,
    role,
    rows: normalizeMultiline(multiline),
    value: localValue !== null && localValue !== void 0 ? localValue : '',
    autoComplete: (0, _autocomplete.autocompleteToHtml)(autocomplete),
    autofocus,
    form: (form === null || form === void 0 ? void 0 : form.nested) ? form.id : undefined
  });

  const multilineClone = Boolean(multiline) === true && /*#__PURE__*/_react.default.createElement("div", {
    "aria-hidden": "true",
    className: (0, _cssUtilities.classNames)(_TextField.default.MultilineClone, className)
  }, localValue, ' '
  /* prevents jump with last return carriage */
  );

  const suffixMarkup = suffix && /*#__PURE__*/_react.default.createElement("div", {
    id: `${id}-suffix`,
    className: _TextField.default.Suffix,
    "aria-hidden": "true",
    onClick: () => {
      var _innerRef$current4;

      return (_innerRef$current4 = innerRef.current) === null || _innerRef$current4 === void 0 ? void 0 : _innerRef$current4.focus();
    }
  }, suffix);

  const actions = children && !disabled && /*#__PURE__*/_react.default.createElement("div", {
    className: _TextField.default.Actions
  }, children);

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, iconMarkup, prefixMarkup, /*#__PURE__*/_react.default.createElement("div", {
    className: fieldWrapperClassName
  }, field, /*#__PURE__*/_react.default.createElement("div", {
    className: backdropClassName
  }), multilineClone), suffixMarkup, actions);
});
exports.Field = Field;

function usePartiallyControlledState(value) {
  const [localValue, setLocalValue] = (0, _react.useState)(value);
  const lastExplicitValue = (0, _react.useRef)(value);
  let valueToReturn = localValue;

  if (lastExplicitValue.current !== value) {
    lastExplicitValue.current = value;
    setLocalValue(value);
    valueToReturn = value;
  }

  return [valueToReturn, setLocalValue];
} // Takes the `type` we allow for a TextField props, and maps it to the
// valid type for an HTML input. Currently, the only difference is
// that we use the full word `telephone` instead of `tel`.


function normalizeType(type) {
  return type === 'telephone' ? 'tel' : type;
}

function normalizeMultiline(multiline) {
  switch (typeof multiline) {
    case 'undefined':
      return false;

    case 'boolean':
      return multiline ? '1' : false;

    case 'number':
      return multiline;
  }
}