"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTheme = useTheme;
exports.useThemeConfiguration = useThemeConfiguration;

var _react = require("react");

var _context = require("./context");

function useTheme() {
  const theme = (0, _react.useContext)(_context.ThemeContext);

  if (theme == null) {
    throw new Error('No theme found in context');
  }

  return theme;
}

function useThemeConfiguration() {
  const theme = useTheme();
  const forceUpdate = useForceUpdate();
  const themeConfigurationRef = (0, _react.useRef)(theme.configuration);
  themeConfigurationRef.current = theme.configuration;
  const internals = (0, _react.useRef)();

  if (internals.current == null) {
    const watchedKeys = new Set();
    const reactiveConfiguration = {};

    for (const key of Object.keys(theme.configuration)) {
      Object.defineProperty(reactiveConfiguration, key, {
        enumerable: true,

        get() {
          watchedKeys.add(key);
          return themeConfigurationRef.current[key];
        }

      });
    }

    internals.current = {
      watchedKeys,
      reactiveConfiguration
    };
  }

  (0, _react.useEffect)(() => {
    const {
      current: currentConfiguration
    } = themeConfigurationRef;
    themeConfigurationRef.current = theme.configuration;

    if ([...internals.current.watchedKeys].some(key => currentConfiguration[key] !== theme.configuration[key])) {
      forceUpdate();
    }

    return theme.on('change', () => {
      const {
        current: currentConfiguration
      } = themeConfigurationRef;
      themeConfigurationRef.current = theme.configuration;

      if ([...internals.current.watchedKeys].some(key => currentConfiguration[key] !== theme.configuration[key])) {
        forceUpdate();
      }
    });
  }, [forceUpdate, theme]);
  return internals.current.reactiveConfiguration;
}

function useForceUpdate() {
  const [, forceUpdate] = (0, _react.useState)({});
  return (0, _react.useCallback)(() => forceUpdate(() => ({})), []);
}