"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _index = require("./index");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  id: _faker.default.random.uuid(),
  selectedItem: _faker.default.random.uuid(),
  onChange: () => null
};
describe('<ToggleButton />', () => {
  it('renders its children', () => {
    const id = _faker.default.random.uuid();

    function Children() {
      return /*#__PURE__*/_react.default.createElement("div", null, "children");
    }

    const toggleButtonGroup = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_index.ToggleButtonGroup, defaultProps, /*#__PURE__*/_react.default.createElement(_index.ToggleButton, {
      id: id
    }, /*#__PURE__*/_react.default.createElement(Children, null))));
    expect(toggleButtonGroup).toContainReactComponent(Children);
  });
  describe('onChange', () => {
    it('triggers onChange when button is selected', () => {
      const id = _faker.default.random.uuid();

      const onChangeSpy = jest.fn();
      const toggleButtonGroup = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_index.ToggleButtonGroup, Object.assign({}, defaultProps, {
        onChange: onChangeSpy
      }), /*#__PURE__*/_react.default.createElement(_index.ToggleButton, {
        id: id
      })));
      toggleButtonGroup.find('button').trigger('onClick');
      expect(onChangeSpy).toHaveBeenCalledWith(id);
    });
  });
  describe('aria-pressed', () => {
    it('aria-pressed corresponds to not selected', () => {
      const id = _faker.default.random.uuid();

      const toggleButtonGroup = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_index.ToggleButtonGroup, defaultProps, /*#__PURE__*/_react.default.createElement(_index.ToggleButton, {
        id: id
      })));
      expect(toggleButtonGroup).toContainReactComponent('button', {
        'aria-pressed': false
      });
    });
    it('aria-pressed corresponds to selected', () => {
      const id = _faker.default.random.uuid();

      const toggleButtonGroup = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_index.ToggleButtonGroup, Object.assign({}, defaultProps, {
        selectedItem: id
      }), /*#__PURE__*/_react.default.createElement(_index.ToggleButton, {
        id: id
      })));
      expect(toggleButtonGroup).toContainReactComponent('button', {
        'aria-pressed': true
      });
    });
  });
});