"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Tooltip = Tooltip;
exports.TooltipContent = TooltipContent;
exports.TooltipArrow = TooltipArrow;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _id = require("../../utilities/id");

var _transition = require("../../utilities/transition");

var _Popper = require("../Popper");

var _TextBlock = require("../TextBlock");

var _TextContainer = require("../TextContainer");

var _Theme = require("../Theme");

var _Tooltip = _interopRequireDefault(require("./Tooltip.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createId = (0, _id.createIdCreator)('Tooltip');

function Tooltip({
  content,
  children
}) {
  const [active, setActive] = (0, _react.useState)(false);
  const buttonRef = (0, _react.useRef)(null);
  const ignoreNonTouchEvents = (0, _react.useRef)(false);
  const transition = (0, _transition.useTransition)(active, {
    exit: 'base'
  });

  function handleKeyDown(event) {
    switch (event.key) {
      case 'Enter':
      case 'Space':
        event.preventDefault();
        setActive(!active);
        break;

      case 'Escape':
      case 'Esc':
        event.preventDefault();
        setActive(false);
        break;
    }
  }

  const id = (0, _id.useId)(undefined, createId);
  const controlId = active ? id : undefined;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Tooltip.default.Wrapper
  }, /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: _Tooltip.default.Button,
    "aria-pressed": active,
    "aria-controls": controlId,
    "aria-describedby": controlId,
    onFocus: () => {
      if (ignoreNonTouchEvents.current) {
        return;
      }

      setActive(true);
    },
    onBlur: () => {
      if (ignoreNonTouchEvents.current) {
        return;
      }

      setActive(false);
    },
    onMouseEnter: () => {
      if (ignoreNonTouchEvents.current) {
        return;
      }

      setActive(true);
    },
    onMouseLeave: () => {
      setActive(false);
    },
    onTouchStart: () => {
      ignoreNonTouchEvents.current = true;
    },
    onClick: () => {
      setActive(!active);
    },
    onKeyDown: handleKeyDown,
    ref: buttonRef
  }, children), transition !== 'exited' && /*#__PURE__*/_react.default.createElement(_Popper.Popper, {
    activator: buttonRef.current,
    preventOverflow: true
  }, /*#__PURE__*/_react.default.createElement(TooltipContent, {
    content: content,
    id: controlId,
    onMouseEnter: () => {
      if (ignoreNonTouchEvents.current) {
        return;
      }

      setActive(true);
    },
    onMouseLeave: () => {
      setActive(false);
    },
    transition: transition
  })));
}

function TooltipContent({
  content,
  id,
  onMouseEnter,
  onMouseLeave,
  transition
}) {
  const {
    clipping,
    spacing
  } = (0, _Popper.usePopper)();
  const {
    tooltip: {
      background,
      opacity = 'translucent',
      borderRadius = 'base',
      textAlignment = 'center'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const offsetX = (clipping.right || clipping.left) && `calc(50% - ${(clipping.right || clipping.left) + spacing}px)`;
  const className = (0, _cssUtilities.classNames)(_Tooltip.default.Tooltip, _Tooltip.default[(0, _cssUtilities.variationName)('transition', transition)], _Tooltip.default[(0, _cssUtilities.variationName)('Tooltip-opacity', opacity)], _Tooltip.default[(0, _cssUtilities.variationName)('Tooltip-borderRadius', borderRadius)], background && _Tooltip.default[(0, _cssUtilities.variationName)('Tooltip-background', background)]);
  const alignment = textAlignment === 'start' ? 'leading' : textAlignment;
  return (
    /*#__PURE__*/

    /* eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions */
    _react.default.createElement("div", {
      id: id,
      role: "tooltip",
      onMouseEnter: onMouseEnter,
      onMouseLeave: onMouseLeave,
      className: className,
      style: { ...(offsetX && {
          transformOrigin: `${offsetX} 120%`
        })
      }
    }, /*#__PURE__*/_react.default.createElement(_TextContainer.TextContainer, {
      alignment: alignment
    }, /*#__PURE__*/_react.default.createElement(_TextBlock.TextBlock, {
      size: "small"
    }, content)), /*#__PURE__*/_react.default.createElement(TooltipArrow, null))
  );
}

function TooltipArrow() {
  const {
    clipping,
    spacing
  } = (0, _Popper.usePopper)();
  const offsetX = (clipping.right || clipping.left) && `calc(${document.dir === 'ltr' ? '-50' : '50'}% - ${(clipping.right || clipping.left) + spacing}px)`;
  const transform = (window.devicePixelRatio || 1) < 2 ? `translate(${offsetX}, 0)` : `translate3d(${offsetX}, 0, 0)`;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Tooltip.default.Arrow,
    style: { ...(offsetX && {
        transform,
        MozTransform: transform,
        webkitTransform: transform
      })
    }
  });
}