"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.View = View;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _responsive = require("../../utilities/responsive");

var _responsiveValue = require("../../utilities/responsiveValue");

var _units = require("../../utilities/units");

var _View = _interopRequireDefault(require("./View.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function View({
  maxInlineSize,
  display = 'block',
  visibility,
  accessibilityVisibility,
  id,
  children,
  ...props
}) {
  const responsiveClassNames = (0, _responsive.useResponsive)(props);
  const style = (0, _responsiveValue.useResponsiveValue)({ ...(maxInlineSize && typeof maxInlineSize === 'number' && {
      base: {
        maxWidth: (0, _units.pixelOrPercent)(maxInlineSize)
      }
    }),
    ...(maxInlineSize && typeof maxInlineSize === 'object' && Object.entries(maxInlineSize).reduce((values, [breakpoint, value]) => {
      if (value) {
        return { ...values,
          [breakpoint]: {
            maxWidth: (0, _units.pixelOrPercent)(value)
          }
        };
      }

      return values;
    }, {}))
  });
  const Element = display === 'inline' ? 'span' : 'div';
  return /*#__PURE__*/_react.default.createElement(Element, {
    className: (0, _cssUtilities.classNames)(_View.default.View, visibility && _View.default[(0, _cssUtilities.variationName)('visibility', visibility)], responsiveClassNames && responsiveClassNames.map(className => _View.default[className])),
    style: style,
    "aria-hidden": accessibilityVisibility === 'hidden',
    id: id
  }, children);
}