"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _View = require("./View");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<View />', () => {
  describe('children', () => {
    it('renders its children', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, null, text, " "));
      expect(view).toContainReactText(text);
    });
  });
  describe('display', () => {
    it('renders a div by default', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, null, text, " "));
      expect(view).toContainReactComponent('div');
    });
    it('renders a span when "inline" is set', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, {
        display: "inline"
      }, text, " "));
      expect(view).toContainReactComponent('span');
    });
    it('renders a div when "block" is set', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, {
        display: "block"
      }, text, " "));
      expect(view).toContainReactComponent('div');
    });
  });
  describe('accessibilityVisibility', () => {
    it('sets aria-hidden to true when accessibilityVisibility is set', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, {
        accessibilityVisibility: "hidden"
      }, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': true
      });
    });
    it('sets aria-hidden to false when accessibilityVisibility is not set', () => {
      const text = 'Snowdevil';
      const view = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_View.View, null, text, " "));
      expect(view).toContainReactComponent('div', {
        'aria-hidden': false
      });
    });
  });
});