"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createMediaQueries = createMediaQueries;
exports.useBreakpoint = useBreakpoint;
exports.BREAKPOINTS = void 0;

var _react = require("react");

const BREAKPOINTS = {
  base: 0,
  small: 750,
  medium: 1000,
  large: 1200
};
exports.BREAKPOINTS = BREAKPOINTS;

function createMediaQueries() {
  return Object.entries(BREAKPOINTS).map(([breakpoint, minWidth], index, breakpoints) => {
    const nextBreakpoint = breakpoints[index + 1];
    const [, maxWidth] = nextBreakpoint ? nextBreakpoint : [];
    const query = maxWidth ? `(min-width: ${minWidth}px) and (max-width: ${maxWidth - 1}px)` : `(min-width: ${minWidth}px)`;
    return {
      breakpoint: breakpoint,
      query
    };
  });
}

function useBreakpoint() {
  const mediaQueries = (0, _react.useMemo)(() => createMediaQueries(), []);
  const getBreakpoint = (0, _react.useCallback)(() => {
    const media = mediaQueries.find(({
      query
    }) => window.matchMedia(query).matches);
    return media ? media.breakpoint : undefined;
  }, [mediaQueries]);
  const [breakpoint, setBreakpoint] = (0, _react.useState)(getBreakpoint());
  (0, _react.useEffect)(() => {
    const onResize = () => {
      const newBreakpoint = getBreakpoint();

      if (breakpoint !== newBreakpoint) {
        setBreakpoint(newBreakpoint);
      }
    };

    onResize();
    window.addEventListener('resize', onResize);
    return () => window.removeEventListener('resize', onResize);
  }, [breakpoint, getBreakpoint, mediaQueries]);
  return breakpoint;
}