"use strict";

var _react = _interopRequireWildcard(require("react"));

var _jestDomMocks = require("@shopify/jest-dom-mocks");

var _testUtilities = require("../test-utilities");

var _breakpoint = require("./breakpoint");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('createMediaQueries', () => {
  it('creates media queries', () => {
    const mediaQueries = (0, _breakpoint.createMediaQueries)();
    expect(mediaQueries).toStrictEqual([{
      breakpoint: 'base',
      query: '(min-width: 0px) and (max-width: 749px)'
    }, {
      breakpoint: 'small',
      query: '(min-width: 750px) and (max-width: 999px)'
    }, {
      breakpoint: 'medium',
      query: '(min-width: 1000px) and (max-width: 1199px)'
    }, {
      breakpoint: 'large',
      query: '(min-width: 1200px)'
    }]);
  });
});
describe('useBreakpoint', () => {
  const spy = jest.fn();

  function Component() {
    const breakpoint = (0, _breakpoint.useBreakpoint)();
    (0, _react.useEffect)(() => {
      spy(breakpoint);
    });
    return null;
  }

  beforeEach(() => {
    _jestDomMocks.matchMedia.mock();
  });
  afterEach(() => {
    _jestDomMocks.matchMedia.restore();

    spy.mockReset();
  });
  it('does not match any breakpoint', () => {
    _jestDomMocks.matchMedia.setMedia(() => ({
      matches: false
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([[undefined]]);
  });
  it('matches base breakpoint', () => {
    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 0px) and (max-width: 749px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['base']]);
  });
  it('matches small breakpoint', () => {
    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 750px) and (max-width: 999px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['small']]);
  });
  it('matches medium breakpoint', () => {
    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 1000px) and (max-width: 1199px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['medium']]);
  });
  it('matches large breakpoint', () => {
    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 1200px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, null));
    expect(spy.mock.calls).toMatchObject([['large']]);
  });
});