"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isFocused = isFocused;
exports.findFirstFocusableNode = findFirstFocusableNode;
exports.findLastFocusableNode = findLastFocusableNode;
exports.findNextFocusableNode = findNextFocusableNode;
exports.FOCUSABLE_SELECTOR = void 0;

function isFocused(element) {
  return document.activeElement === element;
}

const FOCUSABLE_SELECTOR = `
  a[href],
  area[href],
  input:not([type="hidden"]):not([disabled]):not([tabindex="-1"]),
  select:not([disabled]),
  textarea:not([disabled]),
  button:not([disabled]):not([tabindex="-1"]),
  iframe,
  object,
  embed,
  [tabindex="0"],
  [contenteditable],
  audio[controls],
  video[controls]`;
/* https://github.com/Shopify/javascript-utilities/blob/master/src/focus.ts */

exports.FOCUSABLE_SELECTOR = FOCUSABLE_SELECTOR;

function findFirstFocusableNode(element, onlyDescendants = true) {
  if (!onlyDescendants && element.matches(FOCUSABLE_SELECTOR)) {
    return element;
  }

  return element.querySelector(FOCUSABLE_SELECTOR);
}

function findLastFocusableNode(element, onlyDescendants = true) {
  if (!onlyDescendants && element.matches(FOCUSABLE_SELECTOR)) {
    return element;
  }

  const allFocusable = element.querySelectorAll(FOCUSABLE_SELECTOR);
  return allFocusable[allFocusable.length - 1];
}

function findNextFocusableNode(node) {
  const allFocusableElements = [...document.querySelectorAll(FOCUSABLE_SELECTOR)];
  const nodeIndex = allFocusableElements.findIndex(currentNode => node === currentNode);

  if (nodeIndex) {
    return allFocusableElements[nodeIndex + 1];
  }

  return null;
}