"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFocusTrap = useFocusTrap;

var _react = require("react");

const FOCUSABLE_ELEMENTS = `
  a[href],
  area[href],
  input:not([type="hidden"]):not([disabled]):not([tabindex="-1"]),
  select:not([disabled]),
  textarea:not([disabled]),
  button:not([disabled]):not([tabindex="-1"]),
  iframe,
  object,
  embed,
  [tabindex="0"],
  [contenteditable],
  audio[controls],
  video[controls]`;

function useFocusTrap({
  preventScroll
} = {
  preventScroll: false
}) {
  const ref = (0, _react.useRef)(null);
  const findFocusableElements = (0, _react.useCallback)(ref => {
    var _ref$current;

    const focusableElements = ref === null || ref === void 0 ? void 0 : (_ref$current = ref.current) === null || _ref$current === void 0 ? void 0 : _ref$current.querySelectorAll(FOCUSABLE_ELEMENTS);

    if (focusableElements && focusableElements.length > 0) {
      const {
        0: firstElement,
        [focusableElements.length - 1]: lastElement
      } = focusableElements;
      return {
        firstElement,
        lastElement
      };
    }

    return {
      firstElement: null,
      lastElement: null
    };
  }, []);
  const setRef = (0, _react.useCallback)(node => {
    if (node) {
      if (!ref.current) {
        ref.current = node;
        setTimeout(() => {
          var _ref$current2;

          ref === null || ref === void 0 ? void 0 : (_ref$current2 = ref.current) === null || _ref$current2 === void 0 ? void 0 : _ref$current2.focus({
            preventScroll
          });
        });
      }
    } else {
      ref.current = null;
    }
  }, [preventScroll]);
  (0, _react.useEffect)(() => {
    const handleKeyDown = event => {
      const {
        firstElement,
        lastElement
      } = findFocusableElements(ref);

      switch (event.key) {
        case 'Tab':
          if (event.shiftKey) {
            if (lastElement && document.activeElement === firstElement) {
              event.preventDefault();
              lastElement.focus();
            }
          } else if (!event.shiftKey) {
            if (firstElement && document.activeElement === lastElement) {
              event.preventDefault();
              firstElement.focus();
            }
          }

          break;
      }
    };

    document.addEventListener('keydown', handleKeyDown);
    return () => {
      document.removeEventListener('keydown', handleKeyDown);
    };
  }, [findFocusableElements]);
  return setRef;
}