"use strict";

var _react = _interopRequireWildcard(require("react"));

var _jestDomMocks = require("@shopify/jest-dom-mocks");

var _testUtilities = require("../test-utilities");

var _responsiveValue = require("./responsiveValue");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('useResponsiveValue', () => {
  const spy = jest.fn();

  function Component({
    values
  }) {
    const value = (0, _responsiveValue.useResponsiveValue)(values);
    (0, _react.useEffect)(() => {
      spy(value);
    });
    return null;
  }

  beforeEach(() => {
    _jestDomMocks.matchMedia.mock();
  });
  afterEach(() => {
    _jestDomMocks.matchMedia.restore();

    spy.mockReset();
  });
  it('returns undefined if no breakpoint matches', () => {
    const values = {
      small: 'small'
    };

    _jestDomMocks.matchMedia.setMedia(() => ({
      matches: false
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[undefined]]);
  });
  it('returns base value if it maches base breakpoint', () => {
    const values = {
      base: 'base'
    };

    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 0px) and (max-width: 749px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.base]]);
  });
  it('returns small value if it maches small breakpoint', () => {
    const values = {
      small: 'small'
    };

    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 750px) and (max-width: 999px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.small]]);
  });
  it('returns medium value if it maches medium breakpoint', () => {
    const values = {
      medium: 'medium'
    };

    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 1000px) and (max-width: 1199px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.medium]]);
  });
  it('returns large value if it maches large breakpoint', () => {
    const values = {
      large: 'large'
    };

    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 1200px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.large]]);
  });
  it('returns closest value if no breakpoint matches', () => {
    const values = {
      small: 'small',
      large: 'large'
    };

    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 750px) and (max-width: 999px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.small]]);
  });
  it('returns closest non undefined value', () => {
    const values = {
      small: 'small',
      medium: null,
      large: undefined
    };

    _jestDomMocks.matchMedia.setMedia(query => ({
      matches: query === '(min-width: 1200px)'
    }));

    (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(Component, {
      values: values
    }));
    expect(spy.mock.calls).toMatchObject([[values.medium]]);
  });
});