"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Button = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const forms_1 = require("../../utilities/forms");
const AppContext_1 = require("../AppContext");
const transition_1 = require("../../utilities/transition");
const Spinner_1 = require("../Spinner");
const Link_1 = require("../Link");
const legacy_1 = require("../../utilities/legacy");
const media_query_1 = require("../../utilities/media-query");
const Connected_1 = require("../Connected");
const Theme_1 = require("../Theme");
const typography_styles_css_1 = __importDefault(require("../../utilities/typography-styles.css"));
const Button_css_1 = __importDefault(require("./Button.css"));
exports.Button = react_1.forwardRef(function Button({ children, submit = false, disabled, onPress, to, subdued, plain, secondary, tertiary, loading = false, fill = false, loadingLabel, accessibilityLabel, underline, appearance, onMouseEnter, }, ref) {
    const href = disabled ? undefined : to;
    const onClick = disabled ? undefined : () => onPress === null || onPress === void 0 ? void 0 : onPress();
    const refsSetter = react_1.useCallback((instance) => {
        if (typeof ref === 'function') {
            ref(instance);
        }
        else if (ref) {
            ref.current = instance;
        }
    }, [ref]);
    const translate = AppContext_1.useTranslate();
    const prefersReducedMotion = media_query_1.usePrefersReducedMotion();
    const transition = transition_1.useTransition(loading, {
        enter: 'slow',
    });
    const connected = Connected_1.useConnected();
    const { primaryButton: { typographyStyle: primaryStyle, loadingStyle: primaryLoading = 'spinner', }, secondaryButton: { typographyStyle: secondaryStyle, loadingStyle: secondaryLoading = 'spinner', }, link: { colorHovered, colorPressed }, } = Theme_1.useThemeConfiguration();
    const form = forms_1.useContainingForm();
    const loadingStyle = secondary ? secondaryLoading : primaryLoading;
    const classes = css_utilities_1.classNames(Button_css_1.default.Button, legacy_1.button, subdued && !plain && Button_css_1.default.subdued, plain && Button_css_1.default.plain, plain &&
        (appearance === 'inheritColor'
            ? Button_css_1.default.appearanceInheritColor
            : Button_css_1.default.appearanceDefault), plain &&
        colorHovered &&
        Button_css_1.default[css_utilities_1.variationName('colorHovered', colorHovered)], plain &&
        colorPressed &&
        Button_css_1.default[css_utilities_1.variationName('colorPressed', colorPressed)], plain && underline && Button_css_1.default.underline, plain && appearance === 'inheritColor' && Button_css_1.default.underline, disabled && Button_css_1.default.disabled, loading && loadingStyle === 'spinner' && Button_css_1.default.loading, fill && Button_css_1.default.fill, loading &&
        loadingStyle === 'spinner' &&
        Button_css_1.default[css_utilities_1.variationName('loading-transition', transition)], connected && Button_css_1.default.connected, secondary && Button_css_1.default.secondary, tertiary && Button_css_1.default.tertiary, loading && loadingStyle === 'progressBar' && Button_css_1.default[loadingStyle]);
    const normalizedLoadingLabel = loadingLabel
        ? loadingLabel
        : translate('processing');
    const contentTypography = secondary
        ? secondaryStyle && typography_styles_css_1.default[secondaryStyle]
        : primaryStyle && typography_styles_css_1.default[primaryStyle];
    const contentClassNames = css_utilities_1.classNames(Button_css_1.default.Content, !plain && contentTypography);
    const content = (<span className={contentClassNames}>
      {loading && loadingStyle === 'progressBar' && prefersReducedMotion
        ? normalizedLoadingLabel
        : children}
    </span>);
    const type = submit ? 'submit' : 'button';
    const loadingMarkup = (<span className={css_utilities_1.classNames(Button_css_1.default.LoadingContent, !prefersReducedMotion && Button_css_1.default.Spinner)}>
      <Spinner_1.Spinner size="small" color="inherit" accessibilityLabel={normalizedLoadingLabel}/>
    </span>);
    if (href) {
        return (<Link_1.UnstyledLink to={href} className={classes} onPress={onPress} ariaBusy={loading} ariaLive={loading ? 'assertive' : 'polite'} ariaLabel={accessibilityLabel}>
        {content}
        {loading && loadingStyle === 'spinner' && loadingMarkup}
      </Link_1.UnstyledLink>);
    }
    return (<button type={type} form={submit && (form === null || form === void 0 ? void 0 : form.nested) ? form.id : undefined} className={classes} disabled={disabled || loading} onClick={onClick} aria-busy={loading} aria-live={loading ? 'assertive' : undefined} aria-label={accessibilityLabel} ref={refsSetter} onMouseEnter={onMouseEnter}>
      {content}
      {loading && loadingStyle === 'spinner' && loadingMarkup}
    </button>);
});
