"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Modal = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const AppContext_1 = require("../AppContext");
const Portal_1 = require("../Portal");
const Heading_1 = require("../Heading");
const Icon_1 = require("../Icon");
const transition_1 = require("../../utilities/transition");
const focusTrap_1 = require("../../utilities/focusTrap");
const id_1 = require("../../utilities/id");
const Modal_css_1 = __importDefault(require("./Modal.css"));
const DEFAULT_IFRAME_CONTENT_HEIGHT = 400;
const createId = id_1.createIdCreator('ModalHeading');
function isIFrameProps(props) {
    return props.src !== undefined;
}
function Modal(_a) {
    var { blocking = false, long = false, onClose, open: openProp = false, title, titleHidden } = _a, props = __rest(_a, ["blocking", "long", "onClose", "open", "title", "titleHidden"]);
    const translate = AppContext_1.useTranslate();
    const [open, setOpen] = react_1.useState(openProp);
    const [iframeHeight, setIframeHeight] = react_1.useState();
    const titleBarRef = react_1.useRef(null);
    const activatorRef = react_1.useRef(null);
    const modalRef = focusTrap_1.useFocusTrap({ preventScroll: true });
    const modalHeadingId = id_1.useId(undefined, createId);
    const transition = transition_1.useTransition(open, { enter: 'fast' });
    const transitionClassName = Modal_css_1.default[css_utilities_1.variationName('transition', transition)];
    const closeModal = react_1.useCallback(() => {
        setOpen(false);
        if ((activatorRef === null || activatorRef === void 0 ? void 0 : activatorRef.current) instanceof HTMLElement)
            activatorRef.current.focus();
        if (onClose)
            onClose();
        document.body.style.overflow = 'auto';
        setIframeHeight(undefined);
    }, [onClose]);
    const handleKeyDown = react_1.useCallback((event) => {
        if ((event.key === 'Escape' || event.key === 'Esc') && !blocking) {
            closeModal();
        }
    }, [blocking, closeModal]);
    react_1.useEffect(() => {
        if (openProp) {
            document.body.style.overflow = 'hidden';
            activatorRef.current = document.activeElement;
            setOpen(true);
        }
        else {
            closeModal();
        }
    }, [openProp, closeModal]);
    react_1.useEffect(() => {
        document.addEventListener('keydown', handleKeyDown, false);
        return () => {
            document.removeEventListener('keydown', handleKeyDown, false);
        };
    }, [handleKeyDown]);
    const handleIFrameLoad = react_1.useCallback((evt) => {
        const iframe = evt.target;
        if (iframe && iframe.contentWindow) {
            try {
                setIframeHeight(iframe.contentWindow.document.body.scrollHeight);
            }
            catch (_a) {
                setIframeHeight(DEFAULT_IFRAME_CONTENT_HEIGHT);
            }
        }
    }, []);
    if (!open)
        return null;
    const ariaLabelOrLabelledby = titleHidden
        ? { 'aria-label': title }
        : { 'aria-labelledby': modalHeadingId };
    const titleMarkup = titleHidden ? (<span />) : (<Heading_1.Heading level={1} id={modalHeadingId}>
      {title}
    </Heading_1.Heading>);
    return (<Portal_1.Portal>
      <div className={Modal_css_1.default.Modal}>
        
        <div className={css_utilities_1.classNames(Modal_css_1.default.Backdrop, transitionClassName)}>
          <div className={css_utilities_1.classNames(Modal_css_1.default.Content, transitionClassName, {
        [Modal_css_1.default['Content-isLong']]: long,
    })} role="dialog" aria-modal 
    /** @see https://dequeuniversity.com/rules/axe/4.1/scrollable-region-focusable?application=axeAPI */
    // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
    tabIndex={0} ref={modalRef} {...ariaLabelOrLabelledby}>
            {(!titleHidden || !blocking) && (<header className={Modal_css_1.default.Header} ref={titleBarRef}>
                {titleMarkup}
                {!blocking && (<button type="button" className={Modal_css_1.default.Button} onClick={() => closeModal()} aria-label={translate('close') || 'Close'}>
                    <Icon_1.Icon source="close" size="large"/>
                  </button>)}
              </header>)}
            {isIFrameProps(props) ? (<iframe src={props.src} name={props.iFrameName} title={props.iFrameTitle || 'body markup'} className={Modal_css_1.default.IFrame} {...(iframeHeight && { style: { height: `${iframeHeight}px` } })} {...(!long && { onLoad: handleIFrameLoad })}/>) : (<div className={Modal_css_1.default.Body}>{props.children}</div>)}
          </div>
        </div>
      </div>
    </Portal_1.Portal>);
}
exports.Modal = Modal;
