"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MoneySummary = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const InlineStack_1 = require("../InlineStack");
const Text_1 = require("../Text");
const Theme_1 = require("../Theme");
const MoneyLine_1 = require("../MoneyLine");
const MoneySummary_css_1 = __importDefault(require("./MoneySummary.css"));
function MoneySummary({ label, value, prefix, children, }) {
    const { moneyLines: { inlineAlignment }, moneySummary: { background, currencyCode = true, separator = true, labelTypographyStyle, currencyTypographyStyle, valueTypographyStyle, }, } = Theme_1.useThemeConfiguration();
    const className = css_utilities_1.classNames(MoneySummary_css_1.default.MoneySummary, background && MoneySummary_css_1.default[css_utilities_1.variationName('background', background)], inlineAlignment &&
        MoneySummary_css_1.default[css_utilities_1.variationName('inlineAlignment', inlineAlignment)]);
    return (<>
      {separator && <MoneyLine_1.MoneyLineSeparator />}
      <div className={className} role="row">
        <div className={MoneySummary_css_1.default.Label} role="rowheader">
          <Text_1.Text size="medium" style={labelTypographyStyle}>
            {label}
          </Text_1.Text>
          {children}
        </div>
        <div className={MoneySummary_css_1.default.Value} role="cell">
          <InlineStack_1.InlineStack alignment="baseline" spacing="tight">
            
            {currencyCode && (<Text_1.Text role={{ type: 'abbreviation' }} size="small" subdued style={currencyTypographyStyle}>
                {prefix}
              </Text_1.Text>)}
            <Text_1.Text emphasized size="extraLarge" style={valueTypographyStyle}>
              {value}
            </Text_1.Text>
          </InlineStack_1.InlineStack>
        </div>
      </div>
    </>);
}
exports.MoneySummary = MoneySummary;
