/// <reference types="react" />
interface RadioControlProps {
    /**
     * A unique identifier for the field. When no `id` is provided,
     * a globally unique value will be used instead.
     */
    id?: string;
    /**
     * An identifier for the field that is unique within the nearest
     * containing `<Form />` component. When you create multiple radio
     * components representing different options for the same choice,
     * each one should have the same `name` property.
     */
    name: string;
    /**
     * Whether the radio is selected. This prop is an alias for `checked`,
     * and can be useful in form libraries that provide a normalized API for
     * dealing with both `boolean` and `string` values. If both `value` and
     * `checked` are provided, `checked` takes precedence.
     */
    value?: boolean;
    /**
     * Whether the radio is selected.
     */
    checked?: boolean;
    /**
     * Whether the radio can be changed.
     */
    disabled?: boolean;
    /**
     * A callback that is run whenever the checkbox is changed. This callback
     * is called with a boolean indicating whether the radio should now be
     * active or inactive. This component is [controlled](https://reactjs.org/docs/forms.html#controlled-components),
     * so you **must** store this value in state and reflect it back in the
     * `checked` or `value` props.
     */
    onChange?(value: boolean): void;
}
export declare function RadioControl({ id: explicitId, name, value, checked, disabled, onChange, }: RadioControlProps): JSX.Element;
export {};
