"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepSecondaryAction = exports.StepPrimaryAction = exports.StepActions = exports.StepSectionShowcase = exports.StepSectionContent = exports.StepSectionHeader = exports.STEP_SECTION_PRIMARY_HEADER_ID = exports.StepSection = exports.StepContent = exports.Step = void 0;
const react_1 = __importDefault(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const Heading_1 = require("../Heading");
const HeadingGroup_1 = require("../HeadingGroup");
const TextBlock_1 = require("../TextBlock");
const TextContainer_1 = require("../TextContainer");
const Theme_1 = require("../Theme");
const Step_css_1 = __importDefault(require("./Step.css"));
function Step({ children }) {
    return <div className={Step_css_1.default.Step}>{children}</div>;
}
exports.Step = Step;
function StepContent({ grouped, children }) {
    const className = css_utilities_1.classNames(Step_css_1.default.Content, { [Step_css_1.default.isGrouped]: grouped });
    return <div className={className}>{children}</div>;
}
exports.StepContent = StepContent;
function StepSection({ children, title }) {
    return (<section aria-label={title} className={Step_css_1.default.Section}>
      {children}
    </section>);
}
exports.StepSection = StepSection;
exports.STEP_SECTION_PRIMARY_HEADER_ID = 'primary-header';
function StepSectionHeader({ title, primary, description, }) {
    return (<TextContainer_1.TextContainer spacing="tight">
      {title ? (<Heading_1.Heading id={primary ? exports.STEP_SECTION_PRIMARY_HEADER_ID : undefined}>
          {title}
        </Heading_1.Heading>) : null}
      {description ? <TextBlock_1.TextBlock>{description}</TextBlock_1.TextBlock> : null}
    </TextContainer_1.TextContainer>);
}
exports.StepSectionHeader = StepSectionHeader;
function StepSectionContent({ children }) {
    return <HeadingGroup_1.HeadingGroup>{children}</HeadingGroup_1.HeadingGroup>;
}
exports.StepSectionContent = StepSectionContent;
function StepSectionShowcase({ children }) {
    return <div className={Step_css_1.default.Showcase}>{children}</div>;
}
exports.StepSectionShowcase = StepSectionShowcase;
function StepActions({ children }) {
    const { actions: { display = 'inline' }, } = Theme_1.useThemeConfiguration();
    const className = css_utilities_1.classNames(Step_css_1.default.Actions, Step_css_1.default[css_utilities_1.variationName('Actions-display', display)]);
    return <div className={className}>{children}</div>;
}
exports.StepActions = StepActions;
function StepPrimaryAction({ children }) {
    return <div className={Step_css_1.default.PrimaryAction}>{children}</div>;
}
exports.StepPrimaryAction = StepPrimaryAction;
function StepSecondaryAction({ children }) {
    return <div className={Step_css_1.default.SecondaryAction}>{children}</div>;
}
exports.StepSecondaryAction = StepSecondaryAction;
