"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Stepper = void 0;
const react_1 = __importStar(require("react"));
const BlockStack_1 = require("../BlockStack");
const TextField_1 = require("../TextField");
const Connected_1 = require("../Connected");
const Button_1 = require("../Button");
const InlineError_1 = require("../InlineError");
const id_1 = require("../../utilities/id");
const createId = id_1.createIdCreator('StepperField');
function Stepper({ label, error, name, min = 0, max, value, step = 1, id: explicitId, required, onChange, onBlur, onFocus, }) {
    const [quantity, setQuantity] = react_1.useState(value);
    const id = id_1.useId(explicitId, createId);
    const errorMarkup = error && (<InlineError_1.InlineError controlID={id}>{error}</InlineError_1.InlineError>);
    const handleChange = react_1.useCallback((factor) => {
        setQuantity((prevQuantity) => {
            const normalizedMax = max === undefined ? Infinity : max;
            const normalizedMin = min === undefined ? -Infinity : min;
            const quantity = prevQuantity ? prevQuantity : 0;
            if (isNaN(quantity)) {
                return 0;
            }
            // Returns the length of decimal places in a number
            const decimalLength = (num) => (num.toString().split('.')[1] || []).length;
            // Making sure the new value has the same length of decimal places as the
            // step / value has.
            const decimalPlaces = Math.max(decimalLength(quantity), decimalLength(step));
            const newQuantity = Math.min(Number(normalizedMax), Math.max(quantity + factor * step, Number(normalizedMin)));
            if (quantity !== newQuantity) {
                onChange === null || onChange === void 0 ? void 0 : onChange(newQuantity.toFixed(decimalPlaces));
            }
            return parseFloat(newQuantity.toFixed(decimalPlaces));
        });
    }, [onChange, step, max, min]);
    return (<BlockStack_1.BlockStack spacing="tight">
      <Connected_1.Connected trailing="auto" leading="auto">
        <Button_1.Button onPress={() => handleChange(-1)}>-</Button_1.Button>
        <TextField_1.TextFieldInternal label={label} type="number" min={min} max={max} step={step} id={id} error={Boolean(error)} name={name} aria-required={required} value={quantity === undefined ? '' : `${quantity}`} required={required} onChange={(value) => {
        setQuantity(Number(value));
        if (onChange) {
            onChange(value);
        }
    }} onBlur={onBlur} onFocus={onFocus}/>
        <Button_1.Button onPress={() => handleChange(1)}>+</Button_1.Button>
      </Connected_1.Connected>
      {errorMarkup}
    </BlockStack_1.BlockStack>);
}
exports.Stepper = Stepper;
