"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tabs = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const Icon_1 = require("../Icon");
const InlineStack_1 = require("../InlineStack");
const id_1 = require("../../utilities/id");
const Tabs_css_1 = __importDefault(require("./Tabs.css"));
const createId = id_1.createIdCreator('Tabs');
const TabsContext = react_1.createContext(null);
/**
 * Tabs are used when there’s multiple ways to display the same information,
 * like a map or list view. When a buyer needs to make a choice, use the
 * OptionList component instead as Buyers are more likely to choose the
 * non-default option. Don’t hide important information in tabs. Limit to two
 * of three tabs and keep labels short to optimize for mobile.
 */
function Tabs({ tabs, selected, ariaLabel, bordered, onChange, children, }) {
    const id = id_1.useId(undefined, createId);
    const tabList = react_1.useRef(null);
    const lastIndex = tabs.length - 1;
    const childrenCount = react_1.Children.count(children);
    const handleKeyDown = react_1.useCallback((event) => {
        const prev = selected - 1 < 0 ? lastIndex : selected - 1;
        const next = selected + 1 > lastIndex ? 0 : selected + 1;
        const handlerMap = new Map([
            ['ArrowLeft', prev],
            ['Left', prev],
            ['ArrowRight', next],
            ['Right', next],
            ['Home', 0],
            ['End', lastIndex],
        ]);
        const newSelected = handlerMap.get(event.key);
        if (newSelected != null) {
            event.preventDefault();
            onChange(newSelected);
        }
    }, [onChange, selected, lastIndex]);
    react_1.useEffect(() => {
        const { current } = tabList;
        if (current == null)
            return;
        current.addEventListener('keydown', handleKeyDown, false);
        return () => {
            current.removeEventListener('keydown', handleKeyDown, false);
        };
    }, [tabList, handleKeyDown]);
    react_1.useEffect(() => {
        if (childrenCount !== tabs.length) {
            // eslint-disable-next-line no-console
            console.warn(`<Tabs /> has ${tabs.length} tabs and ${childrenCount} children. A mismatch will cause some content to be unavailable.`);
        }
    }, [childrenCount, tabs.length]);
    const tabsMarkup = [];
    const panelsMarkup = [];
    react_1.Children.forEach(children, (child, index) => {
        const tab = tabs[index];
        if (tab != null) {
            const { label, icon } = typeof tab === 'string' ? { label: tab, icon: undefined } : tab;
            tabsMarkup.push(<Tab {...{ label, icon, selected, onChange, id }} index={index} key={label}/>);
        }
        panelsMarkup.push(<TabPanel index={index}>{child}</TabPanel>);
    });
    return (<TabsContext.Provider value={{ id, selected, bordered }}>
      <div className={Tabs_css_1.default.Tabs}>
        <div ref={tabList} role="tablist" aria-label={ariaLabel} className={Tabs_css_1.default.TabList}>
          {tabsMarkup}
        </div>
        {panelsMarkup}
      </div>
    </TabsContext.Provider>);
}
exports.Tabs = Tabs;
function Tab({ label, icon, index, selected: selectedIndex, onChange, id, }) {
    if (index == null) {
        throw new Error('`index` is missing');
    }
    const tabRef = react_1.useRef(null);
    const mountedRef = react_1.useRef(false);
    const selected = selectedIndex === index;
    const markup = icon == null ? (label) : (<InlineStack_1.InlineStack spacing="extraTight" blockAlignment="center">
        <Icon_1.Icon source={icon} size="large"/>
        <span>{label}</span>
      </InlineStack_1.InlineStack>);
    react_1.useEffect(() => {
        if (tabRef.current && selected && mountedRef.current)
            tabRef.current.focus();
        else
            mountedRef.current = true;
    }, [tabRef, selected]);
    return (<button type="button" role="tab" tabIndex={selected ? 0 : -1} aria-selected={selected} id={`${id}Tab${index}`} aria-controls={`${id}TabPanel${index}`} onClick={() => onChange(index)} className={css_utilities_1.classNames(Tabs_css_1.default.Tab, selected && Tabs_css_1.default.selected)} ref={tabRef}>
      {markup}
    </button>);
}
function TabPanel({ index, children }) {
    const { selected: selectedIndex, id, bordered } = useTabs();
    const selected = selectedIndex === index;
    return (<div role="tabpanel" id={`${id}TabPanel${index}`} aria-labelledby={`${id}Tab${index}`} hidden={!selected} className={css_utilities_1.classNames(Tabs_css_1.default.TabPanel, bordered && Tabs_css_1.default.bordered)}>
      {children}
    </div>);
}
function useTabs() {
    const context = react_1.useContext(TabsContext);
    if (context == null) {
        throw new Error('No tabs found in context');
    }
    return context;
}
