"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useThemeConfiguration = exports.useTheme = void 0;
const react_1 = require("react");
const context_1 = require("./context");
function useTheme() {
    const theme = react_1.useContext(context_1.ThemeContext);
    if (theme == null) {
        throw new Error('No theme found in context');
    }
    return theme;
}
exports.useTheme = useTheme;
function useThemeConfiguration() {
    const theme = useTheme();
    const forceUpdate = useForceUpdate();
    const themeConfigurationRef = react_1.useRef(theme.configuration);
    themeConfigurationRef.current = theme.configuration;
    const internals = react_1.useRef();
    if (internals.current == null) {
        const watchedKeys = new Set();
        const reactiveConfiguration = {};
        for (const key of Object.keys(theme.configuration)) {
            Object.defineProperty(reactiveConfiguration, key, {
                enumerable: true,
                get() {
                    watchedKeys.add(key);
                    return themeConfigurationRef.current[key];
                },
            });
        }
        internals.current = {
            watchedKeys,
            reactiveConfiguration,
        };
    }
    react_1.useEffect(() => {
        const { current: currentConfiguration } = themeConfigurationRef;
        themeConfigurationRef.current = theme.configuration;
        if ([...internals.current.watchedKeys].some((key) => currentConfiguration[key] !== theme.configuration[key])) {
            forceUpdate();
        }
        return theme.on('change', () => {
            const { current: currentConfiguration } = themeConfigurationRef;
            themeConfigurationRef.current = theme.configuration;
            if ([...internals.current.watchedKeys].some((key) => currentConfiguration[key] !== theme.configuration[key])) {
                forceUpdate();
            }
        });
    }, [forceUpdate, theme]);
    return internals.current.reactiveConfiguration;
}
exports.useThemeConfiguration = useThemeConfiguration;
function useForceUpdate() {
    const [, forceUpdate] = react_1.useState({});
    return react_1.useCallback(() => forceUpdate(() => ({})), []);
}
