"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TooltipArrow = exports.TooltipContent = exports.Tooltip = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const id_1 = require("../../utilities/id");
const transition_1 = require("../../utilities/transition");
const Popper_1 = require("../Popper");
const TextBlock_1 = require("../TextBlock");
const TextContainer_1 = require("../TextContainer");
const Theme_1 = require("../Theme");
const Tooltip_css_1 = __importDefault(require("./Tooltip.css"));
const createId = id_1.createIdCreator('Tooltip');
function Tooltip({ content, children }) {
    const [active, setActive] = react_1.useState(false);
    const buttonRef = react_1.useRef(null);
    const ignoreNonTouchEvents = react_1.useRef(false);
    const transition = transition_1.useTransition(active, {
        exit: 'base',
    });
    function handleKeyDown(event) {
        switch (event.key) {
            case 'Enter':
            case 'Space':
                event.preventDefault();
                setActive(!active);
                break;
            case 'Escape':
            case 'Esc':
                event.preventDefault();
                setActive(false);
                break;
        }
    }
    const id = id_1.useId(undefined, createId);
    const controlId = active ? id : undefined;
    return (<div className={Tooltip_css_1.default.Wrapper}>
      <button type="button" className={Tooltip_css_1.default.Button} aria-pressed={active} aria-controls={controlId} aria-describedby={controlId} onFocus={() => {
        if (ignoreNonTouchEvents.current) {
            return;
        }
        setActive(true);
    }} onBlur={() => {
        if (ignoreNonTouchEvents.current) {
            return;
        }
        setActive(false);
    }} onMouseEnter={() => {
        if (ignoreNonTouchEvents.current) {
            return;
        }
        setActive(true);
    }} onMouseLeave={() => {
        setActive(false);
    }} onTouchStart={() => {
        ignoreNonTouchEvents.current = true;
    }} onClick={() => {
        setActive(!active);
    }} onKeyDown={handleKeyDown} ref={buttonRef}>
        {children}
      </button>
      {transition !== 'exited' && (<Popper_1.Popper activator={buttonRef.current} preventOverflow>
          <TooltipContent content={content} id={controlId} onMouseEnter={() => {
        if (ignoreNonTouchEvents.current) {
            return;
        }
        setActive(true);
    }} onMouseLeave={() => {
        setActive(false);
    }} transition={transition}/>
        </Popper_1.Popper>)}
    </div>);
}
exports.Tooltip = Tooltip;
function TooltipContent({ content, id, onMouseEnter, onMouseLeave, transition, }) {
    const { clipping, spacing } = Popper_1.usePopper();
    const { tooltip: { background, opacity = 'translucent', borderRadius = 'base', textAlignment = 'center', }, } = Theme_1.useThemeConfiguration();
    const offsetX = (clipping.right || clipping.left) &&
        `calc(50% - ${(clipping.right || clipping.left) + spacing}px)`;
    const className = css_utilities_1.classNames(Tooltip_css_1.default.Tooltip, Tooltip_css_1.default[css_utilities_1.variationName('transition', transition)], Tooltip_css_1.default[css_utilities_1.variationName('Tooltip-opacity', opacity)], Tooltip_css_1.default[css_utilities_1.variationName('Tooltip-borderRadius', borderRadius)], background && Tooltip_css_1.default[css_utilities_1.variationName('Tooltip-background', background)]);
    const alignment = textAlignment === 'start' ? 'leading' : textAlignment;
    return (
    /* eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions */
    <div id={id} role="tooltip" onMouseEnter={onMouseEnter} onMouseLeave={onMouseLeave} className={className} style={Object.assign({}, (offsetX && {
        transformOrigin: `${offsetX} 120%`,
    }))}>
      <TextContainer_1.TextContainer alignment={alignment}>
        <TextBlock_1.TextBlock size="small">{content}</TextBlock_1.TextBlock>
      </TextContainer_1.TextContainer>
      <TooltipArrow />
    </div>);
}
exports.TooltipContent = TooltipContent;
function TooltipArrow() {
    const { clipping, spacing } = Popper_1.usePopper();
    const offsetX = (clipping.right || clipping.left) &&
        `calc(${document.dir === 'ltr' ? '-50' : '50'}% - ${(clipping.right || clipping.left) + spacing}px)`;
    const transform = (window.devicePixelRatio || 1) < 2
        ? `translate(${offsetX}, 0)`
        : `translate3d(${offsetX}, 0, 0)`;
    return (<div className={Tooltip_css_1.default.Arrow} style={Object.assign({}, (offsetX && {
        transform,
        MozTransform: transform,
        webkitTransform: transform,
    }))}/>);
}
exports.TooltipArrow = TooltipArrow;
