"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const dom_1 = require("@quilted/react-testing/dom");
const View_1 = require("./View");
describe('<View />', () => {
    describe('children', () => {
        it('renders its children', () => {
            const text = 'Snowdevil';
            const view = dom_1.mount(<View_1.View>{text} </View_1.View>);
            expect(view).toContainReactText(text);
        });
    });
    describe('display', () => {
        it('renders a div by default', () => {
            const text = 'Snowdevil';
            const view = dom_1.mount(<View_1.View>{text} </View_1.View>);
            expect(view).toContainReactComponent('div');
        });
        it('renders a span when "inline" is set', () => {
            const text = 'Snowdevil';
            const view = dom_1.mount(<View_1.View display="inline">{text} </View_1.View>);
            expect(view).toContainReactComponent('span');
        });
        it('renders a div when "block" is set', () => {
            const text = 'Snowdevil';
            const view = dom_1.mount(<View_1.View display="block">{text} </View_1.View>);
            expect(view).toContainReactComponent('div');
        });
    });
    describe('accessibilityVisibility', () => {
        it('sets aria-hidden to true when accessibilityVisibility is set', () => {
            const text = 'Snowdevil';
            const view = dom_1.mount(<View_1.View accessibilityVisibility="hidden">{text} </View_1.View>);
            expect(view).toContainReactComponent('div', { 'aria-hidden': true });
        });
        it('sets aria-hidden to false when accessibilityVisibility is not set', () => {
            const text = 'Snowdevil';
            const view = dom_1.mount(<View_1.View>{text} </View_1.View>);
            expect(view).toContainReactComponent('div', { 'aria-hidden': false });
        });
    });
});
