"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useBreakpoint = exports.createMediaQueries = exports.BREAKPOINTS = void 0;
const react_1 = require("react");
exports.BREAKPOINTS = {
    base: 0,
    small: 750,
    medium: 1000,
    large: 1200,
};
function createMediaQueries() {
    return Object.entries(exports.BREAKPOINTS).map(([breakpoint, minWidth], index, breakpoints) => {
        const nextBreakpoint = breakpoints[index + 1];
        const [, maxWidth] = nextBreakpoint ? nextBreakpoint : [];
        const query = maxWidth
            ? `(min-width: ${minWidth}px) and (max-width: ${maxWidth - 1}px)`
            : `(min-width: ${minWidth}px)`;
        return {
            breakpoint: breakpoint,
            query,
        };
    });
}
exports.createMediaQueries = createMediaQueries;
function useBreakpoint() {
    const mediaQueries = react_1.useMemo(() => createMediaQueries(), []);
    const getBreakpoint = react_1.useCallback(() => {
        const media = mediaQueries.find(({ query }) => window.matchMedia(query).matches);
        return media ? media.breakpoint : undefined;
    }, [mediaQueries]);
    const [breakpoint, setBreakpoint] = react_1.useState(getBreakpoint());
    react_1.useEffect(() => {
        const onResize = () => {
            const newBreakpoint = getBreakpoint();
            if (breakpoint !== newBreakpoint) {
                setBreakpoint(newBreakpoint);
            }
        };
        onResize();
        window.addEventListener('resize', onResize);
        return () => window.removeEventListener('resize', onResize);
    }, [breakpoint, getBreakpoint, mediaQueries]);
    return breakpoint;
}
exports.useBreakpoint = useBreakpoint;
