"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useResponsive = exports.convertLogicalProps = exports.generateResponsiveClassnames = void 0;
const css_utilities_1 = require("@shopify/css-utilities");
const classNamesMap = {
    padding: [
        'paddingInlineStart',
        'paddingInlineEnd',
        'paddingBlockStart',
        'paddingBlockEnd',
    ],
    paddingInline: ['paddingInlineStart', 'paddingInlineEnd'],
    paddingInlineStart: 'paddingInlineStart',
    paddingInlineEnd: 'paddingInlineEnd',
    paddingBlock: ['paddingBlockStart', 'paddingBlockEnd'],
    paddingBlockStart: 'paddingBlockStart',
    paddingBlockEnd: 'paddingBlockEnd',
    background: 'background',
    border: [
        'borderInlineStart',
        'borderInlineEnd',
        'borderBlockStart',
        'borderBlockEnd',
    ],
    borderInline: ['borderInlineStart', 'borderInlineEnd'],
    borderInlineStart: 'borderInlineStart',
    borderInlineEnd: 'borderInlineEnd',
    borderBlock: ['borderBlockStart', 'borderBlockEnd'],
    borderBlockStart: 'borderBlockStart',
    borderBlockEnd: 'borderBlockEnd',
    borderWidth: [
        'borderWidthInlineStart',
        'borderWidthInlineEnd',
        'borderWidthBlockStart',
        'borderWidthBlockEnd',
    ],
    borderWidthInline: ['borderWidthInlineStart', 'borderWidthInlineEnd'],
    borderWidthInlineStart: 'borderWidthInlineStart',
    borderWidthInlineEnd: 'borderWidthInlineEnd',
    borderWidthBlock: ['borderWidthBlockStart', 'borderWidthBlockEnd'],
    borderWidthBlockStart: 'borderWidthBlockStart',
    borderWidthBlockEnd: 'borderWidthBlockEnd',
    borderColor: [
        'borderColorInlineStart',
        'borderColorInlineEnd',
        'borderColorBlockStart',
        'borderColorBlockEnd',
    ],
    borderRadius: [
        'borderRadiusInlineStart',
        'borderRadiusInlineEnd',
        'borderRadiusBlockStart',
        'borderRadiusBlockEnd',
    ],
    borderRadiusInline: ['borderRadiusInlineStart', 'borderRadiusInlineEnd'],
    borderRadiusInlineStart: 'borderRadiusInlineStart',
    borderRadiusInlineEnd: 'borderRadiusInlineEnd',
    borderRadiusBlock: ['borderRadiusBlockStart', 'borderRadiusBlockEnd'],
    borderRadiusBlockStart: 'borderRadiusBlockStart',
    borderRadiusBlockEnd: 'borderRadiusBlockEnd',
    spacing: 'spacing',
    stack: 'stack',
};
function generateResponsiveClassnames(props, breakpoint) {
    return Object.entries(props)
        .map(([prop, value]) => [prop, value == null ? value : `${value}`])
        .filter(([prop, value]) => classNamesMap[prop] && value)
        .reduce((classNames, [prop, value]) => {
        const property = classNamesMap[prop];
        if (Array.isArray(property)) {
            return [
                ...classNames,
                ...property.map((property) => breakpoint && breakpoint !== 'base'
                    ? css_utilities_1.variationName(css_utilities_1.variationName(breakpoint, property), value)
                    : css_utilities_1.variationName(property, value)),
            ];
        }
        return [
            ...classNames,
            breakpoint && breakpoint !== 'base'
                ? css_utilities_1.variationName(css_utilities_1.variationName(breakpoint, property), value)
                : css_utilities_1.variationName(property, value),
        ];
    }, []);
}
exports.generateResponsiveClassnames = generateResponsiveClassnames;
function convertLogicalProps(prop, value) {
    if (Array.isArray(value)) {
        if (value.length === 2) {
            const [block, inline] = value;
            return {
                [`${prop}Block`]: block,
                [`${prop}Inline`]: inline,
            };
        }
        else if (value.length === 4) {
            const [blockStart, inlineEnd, blockEnd, inlineStart] = value;
            return {
                [`${prop}BlockStart`]: blockStart,
                [`${prop}InlineEnd`]: inlineEnd,
                [`${prop}BlockEnd`]: blockEnd,
                [`${prop}InlineStart`]: inlineStart,
            };
        }
    }
    return { [prop]: value };
}
exports.convertLogicalProps = convertLogicalProps;
function useResponsive(props) {
    return Object.entries(props).reduce((classNames, [prop, values]) => {
        if (Array.isArray(values) || typeof values !== 'object') {
            return [
                ...classNames,
                ...generateResponsiveClassnames(convertLogicalProps(prop, values)),
            ];
        }
        return [
            ...classNames,
            ...Object.entries(values)
                .map(([breakpoint, value]) => generateResponsiveClassnames(convertLogicalProps(prop, value), breakpoint))
                .reduce((classNames, className) => classNames.concat(className), []),
        ];
    }, []);
}
exports.useResponsive = useResponsive;
