"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const jest_dom_mocks_1 = require("@shopify/jest-dom-mocks");
const test_utilities_1 = require("../test-utilities");
const responsiveValue_1 = require("./responsiveValue");
describe('useResponsiveValue', () => {
    const spy = jest.fn();
    function Component({ values }) {
        const value = responsiveValue_1.useResponsiveValue(values);
        react_1.useEffect(() => {
            spy(value);
        });
        return null;
    }
    beforeEach(() => {
        jest_dom_mocks_1.matchMedia.mock();
    });
    afterEach(() => {
        jest_dom_mocks_1.matchMedia.restore();
        spy.mockReset();
    });
    it('returns undefined if no breakpoint matches', () => {
        const values = {
            small: 'small',
        };
        jest_dom_mocks_1.matchMedia.setMedia(() => ({
            matches: false,
        }));
        test_utilities_1.mountWithContext(<Component values={values}/>);
        expect(spy.mock.calls).toMatchObject([[undefined]]);
    });
    it('returns base value if it maches base breakpoint', () => {
        const values = {
            base: 'base',
        };
        jest_dom_mocks_1.matchMedia.setMedia((query) => ({
            matches: query === '(min-width: 0px) and (max-width: 749px)',
        }));
        test_utilities_1.mountWithContext(<Component values={values}/>);
        expect(spy.mock.calls).toMatchObject([[values.base]]);
    });
    it('returns small value if it maches small breakpoint', () => {
        const values = {
            small: 'small',
        };
        jest_dom_mocks_1.matchMedia.setMedia((query) => ({
            matches: query === '(min-width: 750px) and (max-width: 999px)',
        }));
        test_utilities_1.mountWithContext(<Component values={values}/>);
        expect(spy.mock.calls).toMatchObject([[values.small]]);
    });
    it('returns medium value if it maches medium breakpoint', () => {
        const values = {
            medium: 'medium',
        };
        jest_dom_mocks_1.matchMedia.setMedia((query) => ({
            matches: query === '(min-width: 1000px) and (max-width: 1199px)',
        }));
        test_utilities_1.mountWithContext(<Component values={values}/>);
        expect(spy.mock.calls).toMatchObject([[values.medium]]);
    });
    it('returns large value if it maches large breakpoint', () => {
        const values = {
            large: 'large',
        };
        jest_dom_mocks_1.matchMedia.setMedia((query) => ({
            matches: query === '(min-width: 1200px)',
        }));
        test_utilities_1.mountWithContext(<Component values={values}/>);
        expect(spy.mock.calls).toMatchObject([[values.large]]);
    });
    it('returns closest value if no breakpoint matches', () => {
        const values = {
            small: 'small',
            large: 'large',
        };
        jest_dom_mocks_1.matchMedia.setMedia((query) => ({
            matches: query === '(min-width: 750px) and (max-width: 999px)',
        }));
        test_utilities_1.mountWithContext(<Component values={values}/>);
        expect(spy.mock.calls).toMatchObject([[values.small]]);
    });
    it('returns closest non undefined value', () => {
        const values = {
            small: 'small',
            medium: null,
            large: undefined,
        };
        jest_dom_mocks_1.matchMedia.setMedia((query) => ({
            matches: query === '(min-width: 1200px)',
        }));
        test_utilities_1.mountWithContext(<Component values={values}/>);
        expect(spy.mock.calls).toMatchObject([[values.medium]]);
    });
});
